@@ -1,27 +1,51 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * file upload functions
- *
- * @package PhpMyAdmin
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\Core;
-use PhpMyAdmin\Message;
-use PhpMyAdmin\Util;
-use PhpMyAdmin\ZipExtension;
 use ZipArchive;
+use const UPLOAD_ERR_CANT_WRITE;
+use const UPLOAD_ERR_EXTENSION;
+use const UPLOAD_ERR_FORM_SIZE;
+use const UPLOAD_ERR_INI_SIZE;
+use const UPLOAD_ERR_NO_FILE;
+use const UPLOAD_ERR_NO_TMP_DIR;
+use const UPLOAD_ERR_OK;
+use const UPLOAD_ERR_PARTIAL;
+use function basename;
+use function bin2hex;
+use function bzopen;
+use function bzread;
+use function extension_loaded;
+use function fclose;
+use function feof;
+use function file_get_contents;
+use function filesize;
+use function fopen;
+use function fread;
+use function function_exists;
+use function gzopen;
+use function gzread;
+use function is_link;
+use function is_readable;
+use function is_string;
+use function is_uploaded_file;
+use function mb_strcut;
+use function move_uploaded_file;
+use function ob_end_clean;
+use function ob_start;
+use function sprintf;
+use function strlen;
+use function tempnam;
+use function trim;
+use function unlink;
 
 /**
  * File wrapper class
  *
  * @todo when uploading a file into a blob field, should we also consider using
  *       chunks like in import? UPDATE `table` SET `field` = `field` + [chunk]
- *
- * @package PhpMyAdmin
  */
 class File
 {
@@ -29,66 +53,52 @@ class File
      * @var string the temporary file name
      * @access protected
      */
-    protected $_name = null;
+    protected $name = null;
 
     /**
      * @var string the content
      * @access protected
      */
-    protected $_content = null;
+    protected $content = null;
 
     /**
      * @var Message|null the error message
      * @access protected
      */
-    protected $_error_message = null;
+    protected $errorMessage = null;
 
     /**
      * @var bool whether the file is temporary or not
      * @access protected
      */
-    protected $_is_temp = false;
+    protected $isTemp = false;
 
     /**
      * @var string type of compression
      * @access protected
      */
-    protected $_compression = null;
+    protected $compression = null;
 
-    /**
-     * @var integer
-     */
-    protected $_offset = 0;
+    /** @var int */
+    protected $offset = 0;
 
-    /**
-     * @var integer size of chunk to read with every step
-     */
-    protected $_chunk_size = 32768;
+    /** @var int size of chunk to read with every step */
+    protected $chunkSize = 32768;
 
-    /**
-     * @var resource|null file handle
-     */
-    protected $_handle = null;
+    /** @var resource|null file handle */
+    protected $handle = null;
 
-    /**
-     * @var boolean whether to decompress content before returning
-     */
-    protected $_decompress = false;
+    /** @var bool whether to decompress content before returning */
+    protected $decompress = false;
 
-    /**
-     * @var string charset of file
-     */
-    protected $_charset = null;
+    /** @var string charset of file */
+    protected $charset = null;
 
-    /**
-     * @var ZipExtension
-     */
+    /** @var ZipExtension */
     private $zipExtension;
 
     /**
-     * constructor
-     *
-     * @param boolean|string $name file name or false
+     * @param bool|string $name file name or false
      *
      * @access public
      */
@@ -98,16 +108,19 @@ class File
             $this->setName($name);
         }
 
-        if (extension_loaded('zip')) {
-            $this->zipExtension = new ZipExtension(new ZipArchive());
+        if (! extension_loaded('zip')) {
+            return;
         }
+
+        $this->zipExtension = new ZipExtension(new ZipArchive());
     }
 
     /**
      * destructor
      *
      * @see     File::cleanUp()
-     * @access  public
+     *
+     * @access public
      */
     public function __destruct()
     {
@@ -117,8 +130,9 @@ class File
     /**
      * deletes file if it is temporary, usually from a moved upload file
      *
-     * @access  public
-     * @return boolean success
+     * @return bool success
+     *
+     * @access public
      */
     public function cleanUp(): bool
     {
@@ -132,30 +146,32 @@ class File
     /**
      * deletes the file
      *
-     * @access  public
-     * @return boolean success
+     * @return bool success
+     *
+     * @access public
      */
     public function delete(): bool
     {
-        return unlink($this->getName());
+        return unlink((string) $this->getName());
     }
 
     /**
      * checks or sets the temp flag for this file
      * file objects with temp flags are deleted with object destruction
      *
-     * @param boolean $is_temp sets the temp flag
+     * @param bool $is_temp sets the temp flag
      *
-     * @return boolean File::$_is_temp
-     * @access  public
+     * @return bool File::$_is_temp
+     *
+     * @access public
      */
     public function isTemp(?bool $is_temp = null): bool
     {
-        if (null !== $is_temp) {
-            $this->_is_temp = $is_temp;
+        if ($is_temp !== null) {
+            $this->isTemp = $is_temp;
         }
 
-        return $this->_is_temp;
+        return $this->isTemp;
     }
 
     /**
@@ -163,43 +179,49 @@ class File
      *
      * @param string|null $name file name
      *
-     * @return void
-     * @access  public
+     * @access public
      */
     public function setName(?string $name): void
     {
-        $this->_name = trim($name);
+        $this->name = trim((string) $name);
     }
 
     /**
      * Gets file content
      *
-     * @return string|false the binary file content,
-     *                      or false if no content
+     * @return string|false|null the binary file content, or false if no content
      *
-     * @access  public
+     * @access public
      */
     public function getRawContent()
     {
-        if (null === $this->_content) {
-            if ($this->isUploaded() && ! $this->checkUploadedFile()) {
-                return false;
-            }
-
-            if (! $this->isReadable()) {
-                return false;
-            }
-
-            if (function_exists('file_get_contents')) {
-                $this->_content = file_get_contents($this->getName());
-            } elseif ($size = filesize($this->getName())) {
-                $handle = fopen($this->getName(), 'rb');
-                $this->_content = fread($handle, $size);
-                fclose($handle);
-            }
+        if ($this->content !== null) {
+            return $this->content;
         }
 
-        return $this->_content;
+        if ($this->isUploaded() && ! $this->checkUploadedFile()) {
+            return false;
+        }
+
+        if (! $this->isReadable()) {
+            return false;
+        }
+
+        if (function_exists('file_get_contents')) {
+            $this->content = file_get_contents((string) $this->getName());
+
+            return $this->content;
+        }
+
+        $size = filesize((string) $this->getName());
+
+        if ($size) {
+            $handle = fopen((string) $this->getName(), 'rb');
+            $this->content = fread($handle, $size);
+            fclose($handle);
+        }
+
+        return $this->content;
     }
 
     /**
@@ -208,42 +230,42 @@ class File
      * @return string|false the binary file content as a string,
      *                      or false if no content
      *
-     * @access  public
+     * @access public
      */
     public function getContent()
     {
         $result = $this->getRawContent();
-        if ($result === false) {
+        if ($result === false || $result === null) {
             return false;
         }
+
         return '0x' . bin2hex($result);
     }
 
     /**
      * Whether file is uploaded.
      *
-     * @access  public
-     *
-     * @return bool
+     * @access public
      */
     public function isUploaded(): bool
     {
-        if (! is_string($this->getName())) {
+        if ($this->getName() === null) {
             return false;
-        } else {
-            return is_uploaded_file($this->getName());
         }
+
+        return is_uploaded_file($this->getName());
     }
 
     /**
      * accessor
      *
-     * @access public
      * @return string|null File::$_name
+     *
+     * @access public
      */
     public function getName(): ?string
     {
-        return $this->_name;
+        return $this->name;
     }
 
     /**
@@ -251,8 +273,9 @@ class File
      *
      * @param string $name name of file uploaded
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
     public function setUploadedFile(string $name): bool
     {
@@ -260,7 +283,8 @@ class File
 
         if (! $this->isUploaded()) {
             $this->setName(null);
-            $this->_error_message = Message::error(__('File was not an uploaded file.'));
+            $this->errorMessage = Message::error(__('File was not an uploaded file.'));
+
             return false;
         }
 
@@ -273,8 +297,9 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
     public function setUploadedFromTblChangeRequest(
         string $key,
@@ -285,50 +310,46 @@ class File
         ) {
             return false;
         }
-        $file = File::fetchUploadedFromTblChangeRequestMultiple(
+        $file = $this->fetchUploadedFromTblChangeRequestMultiple(
             $_FILES['fields_upload'],
             $rownumber,
             $key
         );
 
-        // check for file upload errors
         switch ($file['error']) {
-        // we do not use the PHP constants here cause not all constants
-        // are defined in all versions of PHP - but the correct constants names
-        // are given as comment
-            case 0: //UPLOAD_ERR_OK:
+            case UPLOAD_ERR_OK:
                 return $this->setUploadedFile($file['tmp_name']);
-            case 4: //UPLOAD_ERR_NO_FILE:
+            case UPLOAD_ERR_NO_FILE:
                 break;
-            case 1: //UPLOAD_ERR_INI_SIZE:
-                $this->_error_message = Message::error(__(
+            case UPLOAD_ERR_INI_SIZE:
+                $this->errorMessage = Message::error(__(
                     'The uploaded file exceeds the upload_max_filesize directive in '
                     . 'php.ini.'
                 ));
                 break;
-            case 2: //UPLOAD_ERR_FORM_SIZE:
-                $this->_error_message = Message::error(__(
+            case UPLOAD_ERR_FORM_SIZE:
+                $this->errorMessage = Message::error(__(
                     'The uploaded file exceeds the MAX_FILE_SIZE directive that was '
                     . 'specified in the HTML form.'
                 ));
                 break;
-            case 3: //UPLOAD_ERR_PARTIAL:
-                $this->_error_message = Message::error(__(
+            case UPLOAD_ERR_PARTIAL:
+                $this->errorMessage = Message::error(__(
                     'The uploaded file was only partially uploaded.'
                 ));
                 break;
-            case 6: //UPLOAD_ERR_NO_TMP_DIR:
-                $this->_error_message = Message::error(__('Missing a temporary folder.'));
+            case UPLOAD_ERR_NO_TMP_DIR:
+                $this->errorMessage = Message::error(__('Missing a temporary folder.'));
                 break;
-            case 7: //UPLOAD_ERR_CANT_WRITE:
-                $this->_error_message = Message::error(__('Failed to write file to disk.'));
+            case UPLOAD_ERR_CANT_WRITE:
+                $this->errorMessage = Message::error(__('Failed to write file to disk.'));
                 break;
-            case 8: //UPLOAD_ERR_EXTENSION:
-                $this->_error_message = Message::error(__('File upload stopped by extension.'));
+            case UPLOAD_ERR_EXTENSION:
+                $this->errorMessage = Message::error(__('File upload stopped by extension.'));
                 break;
             default:
-                $this->_error_message = Message::error(__('Unknown error in file upload.'));
-        } // end switch
+                $this->errorMessage = Message::error(__('Unknown error in file upload.'));
+        }
 
         return false;
     }
@@ -357,7 +378,8 @@ class File
      * @param string $key       key to process
      *
      * @return array
-     * @access  public
+     *
+     * @access public
      * @static
      */
     public function fetchUploadedFromTblChangeRequestMultiple(
@@ -365,15 +387,13 @@ class File
         string $rownumber,
         string $key
     ): array {
-        $new_file = [
+        return [
             'name' => $file['name']['multi_edit'][$rownumber][$key],
             'type' => $file['type']['multi_edit'][$rownumber][$key],
             'size' => $file['size']['multi_edit'][$rownumber][$key],
             'tmp_name' => $file['tmp_name']['multi_edit'][$rownumber][$key],
             'error' => $file['error']['multi_edit'][$rownumber][$key],
         ];
-
-        return $new_file;
     }
 
     /**
@@ -382,8 +402,9 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
     public function setSelectedFromTblChangeRequest(
         string $key,
@@ -404,23 +425,25 @@ class File
     /**
      * Returns possible error message.
      *
-     * @access  public
      * @return Message|null error message
+     *
+     * @access public
      */
     public function getError(): ?Message
     {
-        return $this->_error_message;
+        return $this->errorMessage;
     }
 
     /**
      * Checks whether there was any error.
      *
-     * @access  public
-     * @return boolean whether an error occurred or not
+     * @return bool whether an error occurred or not
+     *
+     * @access public
      */
     public function isError(): bool
     {
-        return $this->_error_message !== null;
+        return $this->errorMessage !== null;
     }
 
     /**
@@ -430,18 +453,23 @@ class File
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
     public function checkTblChangeForm(string $key, string $rownumber): bool
     {
         if ($this->setUploadedFromTblChangeRequest($key, $rownumber)) {
             // well done ...
-            $this->_error_message = null;
+            $this->errorMessage = null;
+
             return true;
-        } elseif ($this->setSelectedFromTblChangeRequest($key, $rownumber)) {
+        }
+
+        if ($this->setSelectedFromTblChangeRequest($key, $rownumber)) {
             // well done ...
-            $this->_error_message = null;
+            $this->errorMessage = null;
+
             return true;
         }
         // all failed, whether just no file uploaded/selected or an error
@@ -454,8 +482,9 @@ class File
      *
      * @param string $name file name
      *
-     * @return boolean success
-     * @access  public
+     * @return bool success
+     *
+     * @access public
      */
     public function setLocalSelectedFile(string $name): bool
     {
@@ -466,14 +495,16 @@ class File
         $this->setName(
             Util::userDir($GLOBALS['cfg']['UploadDir']) . Core::securePath($name)
         );
-        if (@is_link($this->getName())) {
-            $this->_error_message = Message::error(__('File is a symbolic link'));
+        if (@is_link((string) $this->getName())) {
+            $this->errorMessage = Message::error(__('File is a symbolic link'));
             $this->setName(null);
+
             return false;
         }
         if (! $this->isReadable()) {
-            $this->_error_message = Message::error(__('File could not be read!'));
+            $this->errorMessage = Message::error(__('File could not be read!'));
             $this->setName(null);
+
             return false;
         }
 
@@ -483,8 +514,9 @@ class File
     /**
      * Checks whether file can be read.
      *
-     * @access  public
-     * @return boolean whether the file is readable or not
+     * @return bool whether the file is readable or not
+     *
+     * @access public
      */
     public function isReadable(): bool
     {
@@ -498,9 +530,10 @@ class File
      * before opening it. The FAQ 1.11 explains how to create the "./tmp"
      * directory - if needed
      *
+     * @return bool whether uploaded file is fine or not
+     *
      * @todo move check of $cfg['TempDir'] into Config?
-     * @access  public
-     * @return boolean whether uploaded file is fine or not
+     * @access public
      */
     public function checkUploadedFile(): bool
     {
@@ -511,27 +544,29 @@ class File
         $tmp_subdir = $GLOBALS['PMA_Config']->getUploadTempDir();
         if ($tmp_subdir === null) {
             // cannot create directory or access, point user to FAQ 1.11
-            $this->_error_message = Message::error(__(
+            $this->errorMessage = Message::error(__(
                 'Error moving the uploaded file, see [doc@faq1-11]FAQ 1.11[/doc].'
             ));
+
             return false;
         }
 
-        $new_file_to_upload = tempnam(
+        $new_file_to_upload = (string) tempnam(
             $tmp_subdir,
-            basename($this->getName())
+            basename((string) $this->getName())
         );
 
         // suppress warnings from being displayed, but not from being logged
         // any file access outside of open_basedir will issue a warning
         ob_start();
         $move_uploaded_file_result = move_uploaded_file(
-            $this->getName(),
+            (string) $this->getName(),
             $new_file_to_upload
         );
         ob_end_clean();
         if (! $move_uploaded_file_result) {
-            $this->_error_message = Message::error(__('Error while moving uploaded file.'));
+            $this->errorMessage = Message::error(__('Error while moving uploaded file.'));
+
             return false;
         }
 
@@ -539,7 +574,8 @@ class File
         $this->isTemp(true);
 
         if (! $this->isReadable()) {
-            $this->_error_message = Message::error(__('Cannot read uploaded file.'));
+            $this->errorMessage = Message::error(__('Cannot read uploaded file.'));
+
             return false;
         }
 
@@ -549,39 +585,40 @@ class File
     /**
      * Detects what compression the file uses
      *
-     * @todo    move file read part into readChunk() or getChunk()
-     * @todo    add support for compression plugins
-     * @access  protected
-     * @return  string|false false on error, otherwise string MIME type of
-     *                       compression, none for none
+     * @return string|false false on error, otherwise string MIME type of
+     *                      compression, none for none
+     *
+     * @todo   move file read part into readChunk() or getChunk()
+     * @todo   add support for compression plugins
+     * @access protected
      */
     protected function detectCompression()
     {
         // suppress warnings from being displayed, but not from being logged
         // f.e. any file access outside of open_basedir will issue a warning
         ob_start();
-        $file = fopen($this->getName(), 'rb');
+        $file = fopen((string) $this->getName(), 'rb');
         ob_end_clean();
 
         if (! $file) {
-            $this->_error_message = Message::error(__('File could not be read!'));
+            $this->errorMessage = Message::error(__('File could not be read!'));
+
             return false;
         }
 
-        $this->_compression = Util::getCompressionMimeType($file);
-        return $this->_compression;
+        $this->compression = Util::getCompressionMimeType($file);
+
+        return $this->compression;
     }
 
     /**
      * Sets whether the content should be decompressed before returned
      *
-     * @param boolean $decompress whether to decompress
-     *
-     * @return void
+     * @param bool $decompress whether to decompress
      */
     public function setDecompressContent(bool $decompress): void
     {
-        $this->_decompress = $decompress;
+        $this->decompress = $decompress;
     }
 
     /**
@@ -591,33 +628,29 @@ class File
      */
     public function getHandle()
     {
-        if (null === $this->_handle) {
+        if ($this->handle === null) {
             $this->open();
         }
-        return $this->_handle;
+
+        return $this->handle;
     }
 
     /**
      * Sets the file handle
      *
      * @param resource $handle file handle
-     *
-     * @return void
      */
     public function setHandle($handle): void
     {
-        $this->_handle = $handle;
+        $this->handle = $handle;
     }
 
-
     /**
      * Sets error message for unsupported compression.
-     *
-     * @return void
      */
     public function errorUnsupported(): void
     {
-        $this->_error_message = Message::error(sprintf(
+        $this->errorMessage = Message::error(sprintf(
             __(
                 'You attempted to load file with unsupported compression (%s). '
                 . 'Either support for it is not implemented or disabled by your '
@@ -629,33 +662,33 @@ class File
 
     /**
      * Attempts to open the file.
-     *
-     * @return bool
      */
     public function open(): bool
     {
-        if (! $this->_decompress) {
-            $this->_handle = @fopen($this->getName(), 'r');
+        if (! $this->decompress) {
+            $this->handle = @fopen((string) $this->getName(), 'r');
         }
 
         switch ($this->getCompression()) {
             case false:
                 return false;
             case 'application/bzip2':
-                if ($GLOBALS['cfg']['BZipDump'] && function_exists('bzopen')) {
-                    $this->_handle = @bzopen($this->getName(), 'r');
-                } else {
+                if (! $GLOBALS['cfg']['BZipDump'] || ! function_exists('bzopen')) {
                     $this->errorUnsupported();
+
                     return false;
                 }
+
+                $this->handle = @bzopen($this->getName(), 'r');
                 break;
             case 'application/gzip':
-                if ($GLOBALS['cfg']['GZipDump'] && function_exists('gzopen')) {
-                    $this->_handle = @gzopen($this->getName(), 'r');
-                } else {
+                if (! $GLOBALS['cfg']['GZipDump'] || ! function_exists('gzopen')) {
                     $this->errorUnsupported();
+
                     return false;
                 }
+
+                $this->handle = @gzopen((string) $this->getName(), 'r');
                 break;
             case 'application/zip':
                 if ($GLOBALS['cfg']['ZipDump'] && function_exists('zip_open')) {
@@ -663,63 +696,62 @@ class File
                 }
 
                 $this->errorUnsupported();
+
                 return false;
             case 'none':
-                $this->_handle = @fopen($this->getName(), 'r');
+                $this->handle = @fopen((string) $this->getName(), 'r');
                 break;
             default:
                 $this->errorUnsupported();
+
                 return false;
         }
 
-        return ($this->_handle !== false);
+        return $this->handle !== false;
     }
 
     /**
      * Opens file from zip
      *
      * @param string|null $specific_entry Entry to open
-     *
-     * @return bool
      */
     public function openZip(?string $specific_entry = null): bool
     {
         $result = $this->zipExtension->getContents($this->getName(), $specific_entry);
         if (! empty($result['error'])) {
-            $this->_error_message = Message::rawError($result['error']);
+            $this->errorMessage = Message::rawError($result['error']);
+
             return false;
         }
-        $this->_content = $result['data'];
-        $this->_offset = 0;
+        $this->content = $result['data'];
+        $this->offset = 0;
+
         return true;
     }
 
     /**
      * Checks whether we've reached end of file
-     *
-     * @return bool
      */
     public function eof(): bool
     {
-        if ($this->_handle !== null) {
-            return feof($this->_handle);
+        if ($this->handle !== null) {
+            return feof($this->handle);
         }
-        return $this->_offset == strlen($this->_content);
+
+        return $this->offset == strlen($this->content);
     }
 
     /**
      * Closes the file
-     *
-     * @return void
      */
     public function close(): void
     {
-        if ($this->_handle !== null) {
-            fclose($this->_handle);
-            $this->_handle = null;
+        if ($this->handle !== null) {
+            fclose($this->handle);
+            $this->handle = null;
         } else {
-            $this->_content = '';
-            $this->_offset = 0;
+            $this->content = '';
+            $this->offset = 0;
         }
         $this->cleanUp();
     }
@@ -728,23 +760,22 @@ class File
      * Reads data from file
      *
      * @param int $size Number of bytes to read
-     *
-     * @return string
      */
     public function read(int $size): string
     {
-        switch ($this->_compression) {
+        switch ($this->compression) {
             case 'application/bzip2':
-                return bzread($this->_handle, $size);
+                return bzread($this->handle, $size);
             case 'application/gzip':
-                return gzread($this->_handle, $size);
+                return gzread($this->handle, $size);
             case 'application/zip':
-                $result = mb_strcut($this->_content, $this->_offset, $size);
-                $this->_offset += strlen($result);
+                $result = mb_strcut($this->content, $this->offset, $size);
+                $this->offset += strlen($result);
+
                 return $result;
             case 'none':
             default:
-                return fread($this->_handle, $size);
+                return fread($this->handle, $size);
         }
     }
 
@@ -755,75 +786,72 @@ class File
      */
     public function getCharset(): string
     {
-        return $this->_charset;
+        return $this->charset;
     }
 
     /**
      * Sets the character set of the file
      *
      * @param string $charset character set of the file
-     *
-     * @return void
      */
     public function setCharset(string $charset): void
     {
-        $this->_charset = $charset;
+        $this->charset = $charset;
     }
 
     /**
      * Returns compression used by file.
      *
      * @return string MIME type of compression, none for none
-     * @access  public
+     *
+     * @access public
      */
     public function getCompression(): string
     {
-        if (null === $this->_compression) {
+        if ($this->compression === null) {
             return $this->detectCompression();
         }
 
-        return $this->_compression;
+        return $this->compression;
     }
 
     /**
      * Returns the offset
      *
-     * @return integer the offset
+     * @return int the offset
      */
     public function getOffset(): int
     {
-        return $this->_offset;
+        return $this->offset;
     }
 
     /**
      * Returns the chunk size
      *
-     * @return integer the chunk size
+     * @return int the chunk size
      */
     public function getChunkSize(): int
     {
-        return $this->_chunk_size;
+        return $this->chunkSize;
     }
 
     /**
      * Sets the chunk size
      *
-     * @param integer $chunk_size the chunk size
-     *
-     * @return void
+     * @param int $chunkSize the chunk size
      */
-    public function setChunkSize(int $chunk_size): void
+    public function setChunkSize(int $chunkSize): void
     {
-        $this->_chunk_size = $chunk_size;
+        $this->chunkSize = $chunkSize;
     }
 
     /**
      * Returns the length of the content in the file
      *
-     * @return integer the length of the file content
+     * @return int the length of the file content
      */
     public function getContentLength(): int
     {
-        return strlen($this->_content);
+        return strlen($this->content);
     }
 }
