@@ -1,36 +1,22 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\CheckUserPrivileges
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\CheckUserPrivileges;
-use PHPUnit\Framework\TestCase;
 
-/**
- * tests for PhpMyAdmin\CheckUserPrivileges
- *
- * @package PhpMyAdmin-test
- */
-class CheckUserPrivilegesTest extends TestCase
+class CheckUserPrivilegesTest extends AbstractTestCase
 {
-    /**
-     * @var CheckUserPrivileges
-     */
+    /** @var CheckUserPrivileges */
     private $checkUserPrivileges;
 
     /**
      * prepares environment for tests
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $GLOBALS['server'] = 1;
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['col_priv'] = false;
@@ -44,142 +30,126 @@ class CheckUserPrivilegesTest extends TestCase
 
     /**
      * Test for getItemsFromShowGrantsRow
-     *
-     * @return void
      */
-    public function testGetItemsFromShowGrantsRow()
+    public function testGetItemsFromShowGrantsRow(): void
     {
         // TEST CASE 1
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON *.* "
-            . "TO 'root'@'localhost' WITH GRANT OPTION";
 
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON *.* TO \'root\'@\'localhost\' WITH GRANT OPTION'
         );
 
         $this->assertEquals(
-            "ALL PRIVILEGES",
+            'ALL PRIVILEGES',
             $show_grants_str
         );
 
         $this->assertEquals(
-            "*",
+            '*',
             $show_grants_dbname
         );
 
         $this->assertEquals(
-            "*",
+            '*',
             $show_grants_tblname
         );
 
         // TEST CASE 2
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON `mysql`.* TO "
-            . "'root'@'localhost' WITH GRANT OPTION";
 
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON `mysql`.* TO \'root\'@\'localhost\' WITH GRANT OPTION'
         );
 
         $this->assertEquals(
-            "ALL PRIVILEGES",
+            'ALL PRIVILEGES',
             $show_grants_str
         );
 
         $this->assertEquals(
-            "mysql",
+            'mysql',
             $show_grants_dbname
         );
 
         $this->assertEquals(
-            "*",
+            '*',
             $show_grants_tblname
         );
 
         // TEST CASE 3
-        $show_grants_full_row = "GRANT SELECT, INSERT, UPDATE, DELETE "
-            . "ON `mysql`.`columns_priv` TO 'root'@'localhost'";
 
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT SELECT, INSERT, UPDATE, DELETE ON `mysql`.`columns_priv` TO \'root\'@\'localhost\''
         );
 
         $this->assertEquals(
-            "SELECT, INSERT, UPDATE, DELETE",
+            'SELECT, INSERT, UPDATE, DELETE',
             $show_grants_str
         );
 
         $this->assertEquals(
-            "mysql",
+            'mysql',
             $show_grants_dbname
         );
 
         $this->assertEquals(
-            "columns_priv",
+            'columns_priv',
             $show_grants_tblname
         );
 
         // TEST CASE 4
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON `cptest\_.`.* TO "
-            . "'cptest'@'localhost'";
 
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON `cptest\_.`.* TO \'cptest\'@\'localhost\''
         );
 
         $this->assertEquals(
-            "cptest\_.",
+            'cptest\_.',
             $show_grants_dbname
         );
 
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON `cptest\_.a.b.c.d.e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y.z`.* TO "
-            . "'cptest'@'localhost'";
-
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON `cptest\_.a.b.c.d.e.f.g.h.i.j.k.'
+                . 'l.m.n.o.p.q.r.s.t.u.v.w.x.y.z`.* TO \'cptest\'@\'localhost\''
         );
 
         $this->assertEquals(
-            "cptest\_.a.b.c.d.e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y.z",
+            'cptest\_.a.b.c.d.e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y.z',
             $show_grants_dbname
         );
     }
 
     /**
      * Test for checkRequiredPrivilegesForAdjust
-     *
-     * @return void
      */
-    public function testCheckRequiredPrivilegesForAdjust()
+    public function testCheckRequiredPrivilegesForAdjust(): void
     {
         // TEST CASE 1
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON *.* "
-            . "TO 'root'@'localhost' WITH GRANT OPTION";
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON *.* TO \'root\'@\'localhost\' WITH GRANT OPTION'
         );
 
         // call the to-be-tested function
@@ -189,23 +159,19 @@ class CheckUserPrivilegesTest extends TestCase
             $show_grants_tblname
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['col_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['db_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['proc_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['table_priv']
         );
 
@@ -213,14 +179,12 @@ class CheckUserPrivilegesTest extends TestCase
         $this->setUp();
 
         // TEST CASE 2
-        $show_grants_full_row = "GRANT ALL PRIVILEGES ON `mysql`.* TO "
-            . "'root'@'localhost' WITH GRANT OPTION";
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT ALL PRIVILEGES ON `mysql`.* TO \'root\'@\'localhost\' WITH GRANT OPTION'
         );
 
         // call the to-be-tested function
@@ -230,23 +194,19 @@ class CheckUserPrivilegesTest extends TestCase
             $show_grants_tblname
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['col_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['db_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['proc_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['table_priv']
         );
 
@@ -254,14 +214,12 @@ class CheckUserPrivilegesTest extends TestCase
         $this->setUp();
 
         // TEST CASE 3
-        $show_grants_full_row = "GRANT SELECT, INSERT, UPDATE, DELETE ON "
-            . "`mysql`.* TO 'root'@'localhost'";
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT SELECT, INSERT, UPDATE, DELETE ON `mysql`.* TO \'root\'@\'localhost\''
         );
 
         // call the to-be-tested function
@@ -271,23 +229,19 @@ class CheckUserPrivilegesTest extends TestCase
             $show_grants_tblname
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['col_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['db_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['proc_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['table_priv']
         );
 
@@ -295,14 +249,12 @@ class CheckUserPrivilegesTest extends TestCase
         $this->setUp();
 
         // TEST CASE 4
-        $show_grants_full_row = "GRANT SELECT, INSERT, UPDATE, DELETE ON "
-            . "`mysql`.`db` TO 'root'@'localhost'";
-        list(
+        [
             $show_grants_str,
             $show_grants_dbname,
-            $show_grants_tblname
-        ) = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
-            $show_grants_full_row
+            $show_grants_tblname,
+        ] = $this->checkUserPrivileges->getItemsFromShowGrantsRow(
+            'GRANT SELECT, INSERT, UPDATE, DELETE ON `mysql`.`db` TO \'root\'@\'localhost\''
         );
 
         // call the to-be-tested function
@@ -312,23 +264,19 @@ class CheckUserPrivilegesTest extends TestCase
             $show_grants_tblname
         );
 
-        $this->assertEquals(
-            false,
+        $this->assertFalse(
             $GLOBALS['col_priv']
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             $GLOBALS['db_priv']
         );
 
-        $this->assertEquals(
-            false,
+        $this->assertFalse(
             $GLOBALS['proc_priv']
         );
 
-        $this->assertEquals(
-            false,
+        $this->assertFalse(
             $GLOBALS['table_priv']
         );
     }
