@@ -1,23 +1,15 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Test for PhpMyAdmin\Gis\GisMultiPolygon
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Gis;
 
 use PhpMyAdmin\Gis\GisMultiPolygon;
-use PhpMyAdmin\Tests\Gis\GisGeomTestCase;
 use TCPDF;
+use function function_exists;
+use function imagecreatetruecolor;
+use function preg_match;
 
-/**
- * Tests for PhpMyAdmin\Gis\GisMultiPolygon class
- *
- * @package PhpMyAdmin-test
- */
 class GisMultiPolygonTest extends GisGeomTestCase
 {
     /**
@@ -31,10 +23,10 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * This method is called before a test is executed.
      *
      * @access protected
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $this->object = GisMultiPolygon::singleton();
     }
 
@@ -43,10 +35,10 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * This method is called after a test is executed.
      *
      * @access protected
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
@@ -55,7 +47,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array common data for data providers
      */
-    private function _getData()
+    private function getData(): array
     {
         return [
             'MULTIPOLYGON' => [
@@ -136,10 +128,10 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGenerateWkt
      */
-    public function providerForTestGenerateWkt()
+    public function providerForTestGenerateWkt(): array
     {
         $temp = [
-            0 => $this->_getData(),
+            0 => $this->getData(),
         ];
 
         $temp1 = $temp;
@@ -191,11 +183,11 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGenerateParams
      */
-    public function providerForTestGenerateParams()
+    public function providerForTestGenerateParams(): array
     {
-        $temp = $this->_getData();
+        $temp = $this->getData();
 
-        $temp1 = $this->_getData();
+        $temp1 = $this->getData();
         $temp1['gis_type'] = 'MULTIPOLYGON';
 
         return [
@@ -212,9 +204,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
                 'MULTIPOLYGON(((35 10,10 20,15 40,45 45,35 10)'
                     . ',(20 30,35 32,30 20,20 30)),((123 0,23 30,17 63,123 0)))',
                 2,
-                [
-                    2 => $temp1,
-                ],
+                [2 => $temp1],
             ],
         ];
     }
@@ -226,9 +216,8 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @param string $shape    expected shape in WKT
      *
      * @dataProvider providerForTestGetShape
-     * @return void
      */
-    public function testGetShape($row_data, $shape): void
+    public function testGetShape(array $row_data, string $shape): void
     {
         $this->assertEquals($this->object->getShape($row_data), $shape);
     }
@@ -238,7 +227,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGetShape
      */
-    public function providerForTestGetShape()
+    public function providerForTestGetShape(): array
     {
         return [
             [
@@ -321,7 +310,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testScaleRow
      */
-    public function providerForTestScaleRow()
+    public function providerForTestScaleRow(): array
     {
         return [
             [
@@ -347,7 +336,6 @@ class GisMultiPolygonTest extends GisGeomTestCase
         ];
     }
 
-
     /**
      * test case for prepareRowAsPng() method
      *
@@ -357,16 +345,15 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @param array    $scale_data array containing data related to scaling
      * @param resource $image      image object
      *
-     * @return void
      * @dataProvider providerForPrepareRowAsPng
      */
     public function testPrepareRowAsPng(
-        $spatial,
-        $label,
-        $fill_color,
-        $scale_data,
+        string $spatial,
+        string $label,
+        string $fill_color,
+        array $scale_data,
         $image
-    ) {
+    ): void {
         $return = $this->object->prepareRowAsPng(
             $spatial,
             $label,
@@ -382,11 +369,12 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsPng() test case
      */
-    public function providerForPrepareRowAsPng()
+    public function providerForPrepareRowAsPng(): array
     {
         if (! function_exists('imagecreatetruecolor')) {
             $this->markTestSkipped('GD extension missing!');
         }
+
         return [
             [
                 'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),'
@@ -414,16 +402,15 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @param array  $scale_data array containing data related to scaling
      * @param TCPDF  $pdf        TCPDF instance
      *
-     * @return void
      * @dataProvider providerForPrepareRowAsPdf
      */
     public function testPrepareRowAsPdf(
-        $spatial,
-        $label,
-        $fill_color,
-        $scale_data,
-        $pdf
-    ) {
+        string $spatial,
+        string $label,
+        string $fill_color,
+        array $scale_data,
+        TCPDF $pdf
+    ): void {
         $return = $this->object->prepareRowAsPdf(
             $spatial,
             $label,
@@ -439,7 +426,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsPdf() test case
      */
-    public function providerForPrepareRowAsPdf()
+    public function providerForPrepareRowAsPdf(): array
     {
         return [
             [
@@ -461,27 +448,26 @@ class GisMultiPolygonTest extends GisGeomTestCase
     /**
      * test case for prepareRowAsSvg() method
      *
-     * @param string $spatial    GIS MULTIPOLYGON object
-     * @param string $label      label for the GIS MULTIPOLYGON object
-     * @param string $fill_color color for the GIS MULTIPOLYGON object
-     * @param array  $scale_data array containing data related to scaling
-     * @param string $output     expected output
+     * @param string $spatial   GIS MULTIPOLYGON object
+     * @param string $label     label for the GIS MULTIPOLYGON object
+     * @param string $fillColor color for the GIS MULTIPOLYGON object
+     * @param array  $scaleData array containing data related to scaling
+     * @param string $output    expected output
      *
-     * @return void
      * @dataProvider providerForPrepareRowAsSvg
      */
     public function testPrepareRowAsSvg(
-        $spatial,
-        $label,
-        $fill_color,
-        $scale_data,
-        $output
-    ) {
+        string $spatial,
+        string $label,
+        string $fillColor,
+        array $scaleData,
+        string $output
+    ): void {
         $string = $this->object->prepareRowAsSvg(
             $spatial,
             $label,
-            $fill_color,
-            $scale_data
+            $fillColor,
+            $scaleData
         );
         $this->assertEquals(1, preg_match($output, $string));
     }
@@ -491,7 +477,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsSvg() test case
      */
-    public function providerForPrepareRowAsSvg()
+    public function providerForPrepareRowAsSvg(): array
     {
         return [
             [
@@ -522,21 +508,20 @@ class GisMultiPolygonTest extends GisGeomTestCase
      * @param string $spatial    GIS MULTIPOLYGON object
      * @param int    $srid       spatial reference ID
      * @param string $label      label for the GIS MULTIPOLYGON object
-     * @param string $fill_color color for the GIS MULTIPOLYGON object
+     * @param array  $fill_color color for the GIS MULTIPOLYGON object
      * @param array  $scale_data array containing data related to scaling
      * @param string $output     expected output
      *
-     * @return void
      * @dataProvider providerForPrepareRowAsOl
      */
     public function testPrepareRowAsOl(
-        $spatial,
-        $srid,
-        $label,
-        $fill_color,
-        $scale_data,
-        $output
-    ) {
+        string $spatial,
+        int $srid,
+        string $label,
+        array $fill_color,
+        array $scale_data,
+        string $output
+    ): void {
         $this->assertEquals(
             $output,
             $this->object->prepareRowAsOl(
@@ -554,7 +539,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsOl() test case
      */
-    public function providerForPrepareRowAsOl()
+    public function providerForPrepareRowAsOl(): array
     {
         return [
             [
@@ -562,39 +547,38 @@ class GisMultiPolygonTest extends GisGeomTestCase
                     . '((105 0,56 20,78 73,105 0)))',
                 4326,
                 'Ol',
-                '#B02EE0',
+                [176, 46, 224],
                 [
                     'minX' => '0',
                     'minY' => '0',
                     'maxX' => '1',
                     'maxY' => '1',
                 ],
-                'bound = new OpenLayers.Bounds(); bound.extend(new OpenLayers.'
-                . 'LonLat(0, 0).transform(new OpenLayers.Projection("EPSG:4326"), '
-                . 'map.getProjectionObject())); bound.extend(new OpenLayers.LonLat'
-                . '(1, 1).transform(new OpenLayers.Projection("EPSG:4326"), map.ge'
-                . 'tProjectionObject()));vectorLayer.addFeatures(new OpenLayers.'
-                . 'Feature.Vector(new OpenLayers.Geometry.MultiPolygon(new Array'
-                . '(new OpenLayers.Geometry.Polygon(new Array(new OpenLayers.Geo'
-                . 'metry.LinearRing(new Array((new OpenLayers.Geometry.Point'
-                . '(136,40)).transform(new OpenLayers.Projection("EPSG:4326"), '
-                . 'map.getProjectionObject()), (new OpenLayers.Geometry.Point(147,'
-                . '83)).transform(new OpenLayers.Projection("EPSG:4326"), map.get'
-                . 'ProjectionObject()), (new OpenLayers.Geometry.Point(16,75)).'
-                . 'transform(new OpenLayers.Projection("EPSG:4326"), map.getPro'
-                . 'jectionObject()), (new OpenLayers.Geometry.Point(136,40)).trans'
-                . 'form(new OpenLayers.Projection("EPSG:4326"), map.getProjection'
-                . 'Object()))))), new OpenLayers.Geometry.Polygon(new Array(new '
-                . 'OpenLayers.Geometry.LinearRing(new Array((new OpenLayers.Geometry'
-                . '.Point(105,0)).transform(new OpenLayers.Projection("EPSG:4326"), '
-                . 'map.getProjectionObject()), (new OpenLayers.Geometry.Point(56,20)'
-                . ').transform(new OpenLayers.Projection("EPSG:4326"), map.getProjec'
-                . 'tionObject()), (new OpenLayers.Geometry.Point(78,73)).transform'
-                . '(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject'
-                . '()), (new OpenLayers.Geometry.Point(105,0)).transform(new Open'
-                . 'Layers.Projection("EPSG:4326"), map.getProjectionObject()))))))'
-                . '), null, {"strokeColor":"#000000","strokeWidth":0.5,"fillColor":'
-                . '"#B02EE0","fillOpacity":0.8,"label":"Ol","fontSize":10}));',
+                'var style = new ol.style.Style({fill: new ol.style.Fill({"color":[176,46,224,0.8]}'
+                . '),stroke: new ol.style.Stroke({"color":[0,0,0],"width":0.5}),text: new ol.style.'
+                . 'Text({"text":"Ol"})});var minLoc = [0, 0];var maxLoc = [1, 1];var ext = ol.exten'
+                . 't.boundingExtent([minLoc, maxLoc]);ext = ol.proj.transformExtent(ext, ol.proj.ge'
+                . 't("EPSG:4326"), ol.proj.get(\'EPSG:3857\'));map.getView().fit(ext, map.getSize()'
+                . ');var polygonArray = [];var arr = [];var lineArr = [];var line = new ol.geom.Lin'
+                . 'earRing(new Array((new ol.geom.Point([136,40]).transform(ol.proj.get("EPSG:4326"'
+                . '), ol.proj.get(\'EPSG:3857\'))).getCoordinates(), (new ol.geom.Point([147,83]).t'
+                . 'ransform(ol.proj.get("EPSG:4326"), ol.proj.get(\'EPSG:3857\'))).getCoordinates()'
+                . ', (new ol.geom.Point([16,75]).transform(ol.proj.get("EPSG:4326"), ol.proj.get(\''
+                . 'EPSG:3857\'))).getCoordinates(), (new ol.geom.Point([136,40]).transform(ol.proj.'
+                . 'get("EPSG:4326"), ol.proj.get(\'EPSG:3857\'))).getCoordinates()));var coord = li'
+                . 'ne.getCoordinates();for (var i = 0; i < coord.length; i++) lineArr.push(coord[i]);arr.'
+                . 'push(lineArr);var polygon = new ol.geom.Polygon(arr);polygonArray.push(polygon);var arr = [];v'
+                . 'ar lineArr = [];var line = new ol.geom.LinearRing(new Array((new ol.geom.Point(['
+                . '105,0]).transform(ol.proj.get("EPSG:4326"), ol.proj.get(\'EPSG:3857\'))).getCoor'
+                . 'dinates(), (new ol.geom.Point([56,20]).transform(ol.proj.get("EPSG:4326"), ol.pr'
+                . 'oj.get(\'EPSG:3857\'))).getCoordinates(), (new ol.geom.Point([78,73]).transform('
+                . 'ol.proj.get("EPSG:4326"), ol.proj.get(\'EPSG:3857\'))).getCoordinates(), (new ol'
+                . '.geom.Point([105,0]).transform(ol.proj.get("EPSG:4326"), ol.proj.get(\'EPSG:3857'
+                . '\'))).getCoordinates()));var coord = line.getCoordinates();for (var i = 0; i < coord.length;'
+                . ' i++) lineArr.push(coord[i]);arr.push(lineArr);var polygon = new ol.geom.Polygon(arr);po'
+                . 'lygonArray.push(polygon);var multiPolygon = new ol.geom.MultiPolygon(polygonArra'
+                . 'y);var feature = new ol.Feature(multiPolygon);feature.setStyle(style);vectorLaye'
+                . 'r.addFeature(feature);',
             ],
         ];
     }
