@@ -1,77 +1,64 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Test for Index class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Index;
-use PhpMyAdmin\Tests\PmaTestCase;
 
-/**
- * Test for Index class
- *
- * @package PhpMyAdmin-test
- */
-class IndexTest extends PmaTestCase
+class IndexTest extends AbstractTestCase
 {
-    private $_params = [];
+    /** @var array */
+    private $params = [];
 
     /**
      * Configures parameters.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
-        $this->_params['Schema'] = "PMA_Schema";
-        $this->_params['Table'] = "PMA_Table";
-        $this->_params['Key_name'] = "PMA_Key_name";
-        $this->_params['Index_choice'] = "PMA_Index_choice";
-        $this->_params['Comment'] = "PMA_Comment";
-        $this->_params['Index_comment'] = "PMA_Index_comment";
-        $this->_params['Non_unique'] = "PMA_Non_unique";
-        $this->_params['Packed'] = "PMA_Packed";
+        parent::setUp();
+        $this->params['Schema'] = 'PMA_Schema';
+        $this->params['Table'] = 'PMA_Table';
+        $this->params['Key_name'] = 'PMA_Key_name';
+        $this->params['Index_choice'] = 'PMA_Index_choice';
+        $this->params['Comment'] = 'PMA_Comment';
+        $this->params['Index_comment'] = 'PMA_Index_comment';
+        $this->params['Non_unique'] = 'PMA_Non_unique';
+        $this->params['Packed'] = 'PMA_Packed';
 
         //test add columns
         $column1 = [
-            "Column_name" => "column1",
-            "Seq_in_index" => "index1",
-            "Collation" => "Collation1",
-            "Cardinality" => "Cardinality1",
-            "Null" => "null1",
+            'Column_name' => 'column1',
+            'Seq_in_index' => 'index1',
+            'Collation' => 'Collation1',
+            'Cardinality' => 'Cardinality1',
+            'Null' => 'null1',
         ];
         $column2 = [
-            "Column_name" => "column2",
-            "Seq_in_index" => "index2",
-            "Collation" => "Collation2",
-            "Cardinality" => "Cardinality2",
-            "Null" => "null2",
+            'Column_name' => 'column2',
+            'Seq_in_index' => 'index2',
+            'Collation' => 'Collation2',
+            'Cardinality' => 'Cardinality2',
+            'Null' => 'null2',
         ];
         $column3 = [
-            "Column_name" => "column3",
-            "Seq_in_index" => "index3",
-            "Collation" => "Collation3",
-            "Cardinality" => "Cardinality3",
-            "Null" => "null3",
+            'Column_name' => 'column3',
+            'Seq_in_index' => 'index3',
+            'Collation' => 'Collation3',
+            'Cardinality' => 'Cardinality3',
+            'Null' => 'null3',
         ];
-        $this->_params['columns'][] = $column1;
-        $this->_params['columns'][] = $column2;
-        $this->_params['columns'][] = $column3;
+        $this->params['columns'][] = $column1;
+        $this->params['columns'][] = $column2;
+        $this->params['columns'][] = $column3;
     }
 
     /**
      * Test for Constructor
-     *
-     * @return void
      */
-    public function testConstructor()
+    public function testConstructor(): void
     {
-        $index = new Index($this->_params);
+        $index = new Index($this->params);
         $this->assertEquals(
             'PMA_Index_comment',
             $index->getComment()
@@ -106,30 +93,13 @@ class IndexTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for getIndexChoices
-     *
-     * @return void
-     */
-    public function testGetIndexChoices()
-    {
-        $index_choices = Index::getIndexChoices();
-        $this->assertCount(5, $index_choices);
-        $this->assertEquals(
-            'PRIMARY,INDEX,UNIQUE,SPATIAL,FULLTEXT',
-            implode(",", $index_choices)
-        );
-    }
-
     /**
      * Test for isUnique
-     *
-     * @return void
      */
-    public function testIsUniquer()
+    public function testIsUniquer(): void
     {
-        $this->_params['Non_unique'] = "0";
-        $index = new Index($this->_params);
+        $this->params['Non_unique'] = '0';
+        $index = new Index($this->params);
         $this->assertTrue(
             $index->isUnique()
         );
@@ -141,16 +111,14 @@ class IndexTest extends PmaTestCase
 
     /**
      * Test for add Columns
-     *
-     * @return void
      */
-    public function testAddColumns()
+    public function testAddColumns(): void
     {
         $index = new Index();
-        $index->addColumns($this->_params['columns']);
-        $this->assertTrue($index->hasColumn("column1"));
-        $this->assertTrue($index->hasColumn("column2"));
-        $this->assertTrue($index->hasColumn("column3"));
+        $index->addColumns($this->params['columns']);
+        $this->assertTrue($index->hasColumn('column1'));
+        $this->assertTrue($index->hasColumn('column2'));
+        $this->assertTrue($index->hasColumn('column3'));
         $this->assertEquals(
             3,
             $index->getColumnCount()
@@ -159,10 +127,8 @@ class IndexTest extends PmaTestCase
 
     /**
      * Test for get Name & set Name
-     *
-     * @return void
      */
-    public function testName()
+    public function testName(): void
     {
         $index = new Index();
         $index->setName('PMA_name');
@@ -172,15 +138,10 @@ class IndexTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Index Column
-     *
-     * @return void
-     */
-    public function testColumns()
+    public function testColumns(): void
     {
         $index = new Index();
-        $index->addColumns($this->_params['columns']);
+        $index->addColumns($this->params['columns']);
 
         $index_columns = $index->getColumns();
         $index_column = $index_columns['column1'];
