@@ -1,53 +1,42 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\IpAllowDeny
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Core;
 use PhpMyAdmin\IpAllowDeny;
-use PHPUnit\Framework\TestCase;
 
 /**
  * PhpMyAdmin\Tests\IpAllowDenyTest class
  *
  * this class is for testing PhpMyAdmin\IpAllowDeny
- *
- * @package PhpMyAdmin-test
  */
-class IpAllowDenyTest extends TestCase
+class IpAllowDenyTest extends AbstractTestCase
 {
-    /**
-     * @var IpAllowDeny
-     */
+    /** @var IpAllowDeny */
     private $ipAllowDeny;
 
     /**
      * Prepares environment for the test.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
-        $GLOBALS['cfg']['Server']['user'] = "pma_username";
+        parent::setUp();
+        $GLOBALS['cfg']['Server']['user'] = 'pma_username';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "allow % 255.255.255.0/4";
+            = 'allow % 255.255.255.0/4';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "allow % from 255.255.2.0/4";
+            = 'allow % from 255.255.2.0/4';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "allow % from 2001:4998:c:a0d:0000:0000:4998:1020";
+            = 'allow % from 2001:4998:c:a0d:0000:0000:4998:1020';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "allow % from 2001:4998:c:a0d:0000:0000:4998:[1001-2010]";
+            = 'allow % from 2001:4998:c:a0d:0000:0000:4998:[1001-2010]';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "allow % from 2001:4998:c:a0d:0000:0000:4998:3020/24";
-        $GLOBALS['cfg']['Server']['AllowDeny']['rules'][] = "deny % 255.255.0.0/8";
+            = 'allow % from 2001:4998:c:a0d:0000:0000:4998:3020/24';
+        $GLOBALS['cfg']['Server']['AllowDeny']['rules'][] = 'deny % 255.255.0.0/8';
         $GLOBALS['cfg']['Server']['AllowDeny']['rules'][]
-            = "deny % from 255.255.0.0/8";
+            = 'deny % from 255.255.0.0/8';
 
         $this->ipAllowDeny = new IpAllowDeny();
     }
@@ -55,16 +44,14 @@ class IpAllowDenyTest extends TestCase
     /**
      * Test for Core::getIp
      *
-     * @param string $remote   remote
-     * @param string $header   header
-     * @param string $expected expected result
-     * @param string $proxyip  proxyip
-     *
-     * @return void
+     * @param string|null $remote   remote
+     * @param string|null $header   header
+     * @param string|bool $expected expected result
+     * @param string      $proxyip  proxyip
      *
      * @dataProvider proxyIPs
      */
-    public function testGetIp($remote, $header, $expected, $proxyip = null): void
+    public function testGetIp(?string $remote, ?string $header, $expected, ?string $proxyip = null): void
     {
         unset($_SERVER['REMOTE_ADDR']);
         unset($_SERVER['TEST_FORWARDED_HEADER']);
@@ -97,7 +84,7 @@ class IpAllowDenyTest extends TestCase
      *
      * @return array
      */
-    public function proxyIPs()
+    public function proxyIPs(): array
     {
         return [
             // Nothing set
@@ -142,136 +129,113 @@ class IpAllowDenyTest extends TestCase
 
     /**
      * Test for ipMaskTest
-     *
-     * @return void
      */
-    public function testIpMaskTest()
+    public function testIpMaskTest(): void
     {
         //IPV4 testing
-        $testRange = "255.255.0.0/8";
-        $ipToTest = "10.0.0.0";
-        $this->assertEquals(
-            false,
+        $testRange = '255.255.0.0/8';
+        $ipToTest = '10.0.0.0';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
 
-        $testRange = "255.255.0.0/4";
-        $ipToTest = "255.3.0.0";
-        $this->assertEquals(
-            true,
+        $testRange = '255.255.0.0/4';
+        $ipToTest = '255.3.0.0';
+        $this->assertTrue(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
 
-        $testRange = "255.255.0.[0-10]";
-        $ipToTest = "255.3.0.3";
-        $this->assertEquals(
-            false,
+        $testRange = '255.255.0.[0-10]';
+        $ipToTest = '255.3.0.3';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
-        $ipToTest = "255.3.0.12";
-        $this->assertEquals(
-            false,
+        $ipToTest = '255.3.0.12';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
 
         //IPV6 testing
         //not range
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $this->assertEquals(
-            true,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $this->assertTrue(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:2020";
-        $this->assertEquals(
-            false,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:2020';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
 
         //range
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:[1001-2010]";
-        $this->assertEquals(
-            true,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:[1001-2010]';
+        $this->assertTrue(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:3020";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:[1001-2010]";
-        $this->assertEquals(
-            false,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:3020';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:[1001-2010]';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
 
         //CDIR
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:[1001-2010]";
-        $this->assertEquals(
-            true,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:[1001-2010]';
+        $this->assertTrue(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
-        $ipToTest = "2001:4998:c:a0d:0000:0000:4998:1000";
-        $testRange = "2001:4998:c:a0d:0000:0000:4998:3020/24";
-        $this->assertEquals(
-            false,
+        $ipToTest = '2001:4998:c:a0d:0000:0000:4998:1000';
+        $testRange = '2001:4998:c:a0d:0000:0000:4998:3020/24';
+        $this->assertFalse(
             $this->ipAllowDeny->ipMaskTest($testRange, $ipToTest)
         );
     }
 
     /**
      * Test for allowDeny
-     *
-     * @return void
      */
-    public function testAllowDeny()
+    public function testAllowDeny(): void
     {
-        $_SERVER['REMOTE_ADDR'] = "";
-        $this->assertEquals(
-            false,
+        $_SERVER['REMOTE_ADDR'] = '';
+        $this->assertFalse(
             $this->ipAllowDeny->allow()
         );
 
-        $_SERVER['REMOTE_ADDR'] = "255.0.1.0";
-        $this->assertEquals(
-            true,
+        $_SERVER['REMOTE_ADDR'] = '255.0.1.0';
+        $this->assertTrue(
             $this->ipAllowDeny->allow()
         );
-        $_SERVER['REMOTE_ADDR'] = "10.0.0.0";
-        $this->assertEquals(
-            false,
+        $_SERVER['REMOTE_ADDR'] = '10.0.0.0';
+        $this->assertFalse(
             $this->ipAllowDeny->allow()
         );
 
-        $_SERVER['REMOTE_ADDR'] = "255.255.0.1";
-        $this->assertEquals(
-            true,
+        $_SERVER['REMOTE_ADDR'] = '255.255.0.1';
+        $this->assertTrue(
             $this->ipAllowDeny->deny()
         );
-        $_SERVER['REMOTE_ADDR'] = "255.124.0.5";
-        $this->assertEquals(
-            true,
+        $_SERVER['REMOTE_ADDR'] = '255.124.0.5';
+        $this->assertTrue(
             $this->ipAllowDeny->deny()
         );
-        $_SERVER['REMOTE_ADDR'] = "122.124.0.5";
-        $this->assertEquals(
-            false,
+        $_SERVER['REMOTE_ADDR'] = '122.124.0.5';
+        $this->assertFalse(
             $this->ipAllowDeny->deny()
         );
 
         //IPV6
-        $_SERVER['REMOTE_ADDR'] = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $this->assertEquals(
-            true,
+        $_SERVER['REMOTE_ADDR'] = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $this->assertTrue(
             $this->ipAllowDeny->allow()
         );
-        $_SERVER['REMOTE_ADDR'] = "2001:4998:c:a0d:0000:0000:4998:1000";
-        $this->assertEquals(
-            false,
+        $_SERVER['REMOTE_ADDR'] = '2001:4998:c:a0d:0000:0000:4998:1000';
+        $this->assertFalse(
             $this->ipAllowDeny->allow()
         );
-        $_SERVER['REMOTE_ADDR'] = "2001:4998:c:a0d:0000:0000:4998:1020";
-        $this->assertEquals(
-            true,
+        $_SERVER['REMOTE_ADDR'] = '2001:4998:c:a0d:0000:0000:4998:1020';
+        $this->assertTrue(
             $this->ipAllowDeny->allow()
         );
     }
