@@ -1,27 +1,12 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for ListDatabase class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\ListDatabase;
-use PhpMyAdmin\Tests\PmaTestCase;
-use ReflectionClass;
 
-$GLOBALS['server'] = 1;
-$GLOBALS['cfg']['Server']['DisableIS'] = false;
-
-/**
- * tests for ListDatabase class
- *
- * @package PhpMyAdmin-test
- */
-class ListDatabaseTest extends PmaTestCase
+class ListDatabaseTest extends AbstractTestCase
 {
     /**
      * ListDatabase instance
@@ -32,37 +17,20 @@ class ListDatabaseTest extends PmaTestCase
 
     /**
      * SetUp for test cases
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        $GLOBALS['server'] = 1;
+        $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['cfg']['Server']['only_db'] = ['single\\_db'];
         $this->object = new ListDatabase();
     }
 
-    /**
-     * Call protected functions by setting visibility to public.
-     *
-     * @param string $name   method name
-     * @param array  $params parameters for the invocation
-     *
-     * @return mixed the output from the protected method.
-     */
-    private function _callProtectedFunction($name, $params)
-    {
-        $class = new ReflectionClass(ListDatabase::class);
-        $method = $class->getMethod($name);
-        $method->setAccessible(true);
-        return $method->invokeArgs($this->object, $params);
-    }
-
     /**
      * Test for ListDatabase::getEmpty
-     *
-     * @return void
      */
-    public function testEmpty()
+    public function testEmpty(): void
     {
         $arr = new ListDatabase();
         $this->assertEquals('', $arr->getEmpty());
@@ -70,39 +38,50 @@ class ListDatabaseTest extends PmaTestCase
 
     /**
      * Test for ListDatabase::exists
-     *
-     * @return void
      */
-    public function testExists()
+    public function testExists(): void
     {
         $arr = new ListDatabase();
-        $this->assertEquals(true, $arr->exists('single_db'));
+        $this->assertTrue($arr->exists('single_db'));
     }
 
-    /**
-     * Test for ListDatabase::getHtmlOptions
-     *
-     * @return void
-     */
-    public function testHtmlOptions()
+    public function testGetList(): void
     {
         $arr = new ListDatabase();
+
+        $GLOBALS['db'] = 'db';
         $this->assertEquals(
-            '<option value="single_db">single_db</option>' . "\n",
-            $arr->getHtmlOptions()
+            [
+                [
+                    'name' => 'single_db',
+                    'is_selected' => false,
+                ],
+            ],
+            $arr->getList()
+        );
+
+        $GLOBALS['db'] = 'single_db';
+        $this->assertEquals(
+            [
+                [
+                    'name' => 'single_db',
+                    'is_selected' => true,
+                ],
+            ],
+            $arr->getList()
         );
     }
 
     /**
      * Test for checkHideDatabase
-     *
-     * @return void
      */
-    public function testCheckHideDatabase()
+    public function testCheckHideDatabase(): void
     {
         $GLOBALS['cfg']['Server']['hide_db'] = 'single\\_db';
         $this->assertEquals(
-            $this->_callProtectedFunction(
+            $this->callFunction(
+                $this->object,
+                ListDatabase::class,
                 'checkHideDatabase',
                 []
             ),
@@ -112,10 +91,8 @@ class ListDatabaseTest extends PmaTestCase
 
     /**
      * Test for getDefault
-     *
-     * @return void
      */
-    public function testGetDefault()
+    public function testGetDefault(): void
     {
         $GLOBALS['db'] = '';
         $this->assertEquals(
