@@ -1,23 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Mime
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\Mime;
-use PHPUnit\Framework\TestCase;
+use function chr;
 
 /**
  * Test for mime detection.
- *
- * @package PhpMyAdmin-test
  */
-class MimeTest extends TestCase
+class MimeTest extends AbstractTestCase
 {
     /**
      * Test for Mime::detect
@@ -25,12 +18,10 @@ class MimeTest extends TestCase
      * @param string $test   MIME to test
      * @param string $output Expected output
      *
-     * @return void
      * @dataProvider providerForTestDetect
      */
-    public function testDetect($test, $output): void
+    public function testDetect(string $test, string $output): void
     {
-
         $this->assertEquals(
             Mime::detect($test),
             $output
@@ -42,7 +33,7 @@ class MimeTest extends TestCase
      *
      * @return array data for testDetect
      */
-    public function providerForTestDetect()
+    public function providerForTestDetect(): array
     {
         return [
             [
