@@ -1,41 +1,29 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Tests for PhpMyAdmin\Navigation\Nodes\NodeEventContainer class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
-use PhpMyAdmin\Tests\PmaTestCase;
-use PhpMyAdmin\Theme;
+use PhpMyAdmin\Tests\AbstractTestCase;
+use PhpMyAdmin\Url;
 
-/**
- * Tests for PhpMyAdmin\Navigation\Nodes\NodeEventContainer class
- *
- * @package PhpMyAdmin-test
- */
-class NodeEventContainerTest extends PmaTestCase
+class NodeEventContainerTest extends AbstractTestCase
 {
     /**
      * SetUp for test cases
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
     }
 
     /**
      * Test for __construct
-     *
-     * @return void
      */
-    public function testConstructor()
+    public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeEventContainer');
         $this->assertArrayHasKey(
@@ -43,7 +31,7 @@ class NodeEventContainerTest extends PmaTestCase
             $parent->links
         );
         $this->assertStringContainsString(
-            'db_events.php',
+            Url::getFromRoute('/database/events'),
             $parent->links['text']
         );
         $this->assertEquals('events', $parent->realName);
