@@ -1,41 +1,28 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Tests for PhpMyAdmin\Navigation\Nodes\NodeIndexContainer class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
-use PhpMyAdmin\Tests\PmaTestCase;
-use PhpMyAdmin\Theme;
+use PhpMyAdmin\Tests\AbstractTestCase;
 
-/**
- * Tests for PhpMyAdmin\Navigation\Nodes\NodeIndexContainer class
- *
- * @package PhpMyAdmin-test
- */
-class NodeIndexContainerTest extends PmaTestCase
+class NodeIndexContainerTest extends AbstractTestCase
 {
     /**
      * SetUp for test cases
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
     }
 
     /**
      * Test for __construct
-     *
-     * @return void
      */
-    public function testConstructor()
+    public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeIndexContainer');
         $this->assertArrayHasKey(
@@ -43,7 +30,7 @@ class NodeIndexContainerTest extends PmaTestCase
             $parent->links
         );
         $this->assertStringContainsString(
-            'tbl_structure.php',
+            'index.php?route=/table/structure',
             $parent->links['text']
         );
         $this->assertEquals('indexes', $parent->realName);
