@@ -1,44 +1,32 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Tests for Node class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
+use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Navigation\NodeFactory;
 use PhpMyAdmin\Navigation\Nodes\Node;
-use PhpMyAdmin\Tests\PmaTestCase;
-use PhpMyAdmin\Theme;
+use PhpMyAdmin\Tests\AbstractTestCase;
 use ReflectionMethod;
 
-/**
- * Tests for Node class
- *
- * @package PhpMyAdmin-test
- */
-class NodeTest extends PmaTestCase
+class NodeTest extends AbstractTestCase
 {
     /**
      * SetUp for test cases
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
     }
 
     /**
      * SetUp for AddNode
-     *
-     * @return void
      */
-    public function testAddNode()
+    public function testAddNode(): void
     {
         $parent = NodeFactory::getInstance('Node', 'parent');
         $child = NodeFactory::getInstance('Node', 'child');
@@ -55,28 +43,22 @@ class NodeTest extends PmaTestCase
 
     /**
      * SetUp for getChild
-     *
-     * @return void
      */
-    public function testGetChildError()
+    public function testGetChildError(): void
     {
         $parent = NodeFactory::getInstance('Node', 'parent');
-        $this->assertEquals(
-            $parent->getChild("foo"),
-            false
+        $this->assertNull(
+            $parent->getChild('foo')
         );
-        $this->assertEquals(
-            $parent->getChild("foo", true),
-            false
+        $this->assertNull(
+            $parent->getChild('foo', true)
         );
     }
 
     /**
      * SetUp for getChild
-     *
-     * @return void
      */
-    public function testRemoveNode()
+    public function testRemoveNode(): void
     {
         $parent = NodeFactory::getInstance('Node', 'parent');
         $child = NodeFactory::getInstance('Node', 'child');
@@ -86,18 +68,15 @@ class NodeTest extends PmaTestCase
             $child
         );
         $parent->removeChild($child->name);
-        $this->assertEquals(
-            $parent->getChild($child->name),
-            false
+        $this->assertNull(
+            $parent->getChild($child->name)
         );
     }
 
     /**
      * SetUp for hasChildren
-     *
-     * @return void
      */
-    public function testNodeHasChildren()
+    public function testNodeHasChildren(): void
     {
         $parent = NodeFactory::getInstance();
         $emptyContainer = NodeFactory::getInstance(
@@ -139,10 +118,8 @@ class NodeTest extends PmaTestCase
 
     /**
      * SetUp for numChildren
-     *
-     * @return void
      */
-    public function testNumChildren()
+    public function testNumChildren(): void
     {
         // start with root node only
         $parent = NodeFactory::getInstance();
@@ -173,10 +150,8 @@ class NodeTest extends PmaTestCase
 
     /**
      * SetUp for parents
-     *
-     * @return void
      */
-    public function testParents()
+    public function testParents(): void
     {
         $parent = NodeFactory::getInstance();
         $this->assertEquals($parent->parents(), []); // exclude self
@@ -197,10 +172,8 @@ class NodeTest extends PmaTestCase
 
     /**
      * SetUp for realParent
-     *
-     * @return void
      */
-    public function testRealParent()
+    public function testRealParent(): void
     {
         $parent = NodeFactory::getInstance();
         $this->assertFalse($parent->realParent());
@@ -213,26 +186,20 @@ class NodeTest extends PmaTestCase
     /**
      * Tests whether Node->hasSiblings() method returns false
      * when the node does not have any siblings.
-     *
-     * @return void
-     * @test
      */
-    public function testHasSiblingsWithNoSiblings()
+    public function testHasSiblingsWithNoSiblings(): void
     {
         $parent = NodeFactory::getInstance();
         $child = NodeFactory::getInstance();
         $parent->addChild($child);
-        $this->assertEquals(false, $child->hasSiblings());
+        $this->assertFalse($child->hasSiblings());
     }
 
     /**
      * Tests whether Node->hasSiblings() method returns true
      * when it actually has siblings.
-     *
-     * @return void
-     * @test
      */
-    public function testHasSiblingsWithSiblings()
+    public function testHasSiblingsWithSiblings(): void
     {
         $parent = NodeFactory::getInstance();
         $firstChild = NodeFactory::getInstance();
@@ -240,7 +207,7 @@ class NodeTest extends PmaTestCase
         $secondChild = NodeFactory::getInstance();
         $parent->addChild($secondChild);
         // Normal case; two Node:NODE type siblings
-        $this->assertEquals(true, $firstChild->hasSiblings());
+        $this->assertTrue($firstChild->hasSiblings());
 
         $parent = NodeFactory::getInstance();
         $firstChild = NodeFactory::getInstance();
@@ -252,22 +219,19 @@ class NodeTest extends PmaTestCase
         );
         $parent->addChild($secondChild);
         // Empty Node::CONTAINER type node should not be considered in hasSiblings()
-        $this->assertEquals(false, $firstChild->hasSiblings());
+        $this->assertFalse($firstChild->hasSiblings());
 
         $grandChild = NodeFactory::getInstance();
         $secondChild->addChild($grandChild);
         // Node::CONTAINER type nodes with children are counted for hasSiblings()
-        $this->assertEquals(true, $firstChild->hasSiblings());
+        $this->assertTrue($firstChild->hasSiblings());
     }
 
     /**
      * It is expected that Node->hasSiblings() method always return true
      * for Nodes that are 3 levels deep (columns and indexes).
-     *
-     * @return void
-     * @test
      */
-    public function testHasSiblingsForNodesAtLevelThree()
+    public function testHasSiblingsForNodesAtLevelThree(): void
     {
         $parent = NodeFactory::getInstance();
         $child = NodeFactory::getInstance();
@@ -278,21 +242,18 @@ class NodeTest extends PmaTestCase
         $grandChild->addChild($greatGrandChild);
 
         // Should return false for node that are two levels deeps
-        $this->assertEquals(false, $grandChild->hasSiblings());
+        $this->assertFalse($grandChild->hasSiblings());
         // Should return true for node that are three levels deeps
-        $this->assertEquals(true, $greatGrandChild->hasSiblings());
+        $this->assertTrue($greatGrandChild->hasSiblings());
     }
 
     /**
      * Tests private method _getWhereClause()
-     *
-     * @return void
-     * @test
      */
-    public function testGetWhereClause()
+    public function testGetWhereClause(): void
     {
         $method = new ReflectionMethod(
-            'PhpMyAdmin\Navigation\Nodes\Node',
+            Node::class,
             'getWhereClause'
         );
         $method->setAccessible(true);
@@ -300,7 +261,7 @@ class NodeTest extends PmaTestCase
         // Vanilla case
         $node = NodeFactory::getInstance();
         $this->assertEquals(
-            "WHERE TRUE ",
+            'WHERE TRUE ',
             $method->invoke($node, 'SCHEMA_NAME')
         );
 
@@ -346,11 +307,8 @@ class NodeTest extends PmaTestCase
     /**
      * Tests getData() method when DisableIS is false and navigation tree
      * grouping enabled.
-     *
-     * @return void
-     * @test
      */
-    public function testGetDataWithEnabledISAndGroupingEnabled()
+    public function testGetDataWithEnabledISAndGroupingEnabled(): void
     {
         $pos = 10;
         $limit = 20;
@@ -359,29 +317,29 @@ class NodeTest extends PmaTestCase
         $GLOBALS['cfg']['FirstLevelNavigationItems'] = $limit;
         $GLOBALS['cfg']['NavigationTreeDbSeparator'] = '_';
 
-        $expectedSql  = "SELECT `SCHEMA_NAME` ";
-        $expectedSql .= "FROM `INFORMATION_SCHEMA`.`SCHEMATA`, ";
-        $expectedSql .= "(";
-        $expectedSql .= "SELECT DB_first_level ";
-        $expectedSql .= "FROM ( ";
-        $expectedSql .= "SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, ";
+        $expectedSql  = 'SELECT `SCHEMA_NAME` ';
+        $expectedSql .= 'FROM `INFORMATION_SCHEMA`.`SCHEMATA`, ';
+        $expectedSql .= '(';
+        $expectedSql .= 'SELECT DB_first_level ';
+        $expectedSql .= 'FROM ( ';
+        $expectedSql .= 'SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, ';
         $expectedSql .= "'_', 1) ";
-        $expectedSql .= "DB_first_level ";
-        $expectedSql .= "FROM INFORMATION_SCHEMA.SCHEMATA ";
-        $expectedSql .= "WHERE TRUE ";
-        $expectedSql .= ") t ";
-        $expectedSql .= "ORDER BY DB_first_level ASC ";
-        $expectedSql .= "LIMIT $pos, $limit";
-        $expectedSql .= ") t2 ";
+        $expectedSql .= 'DB_first_level ';
+        $expectedSql .= 'FROM INFORMATION_SCHEMA.SCHEMATA ';
+        $expectedSql .= 'WHERE TRUE ';
+        $expectedSql .= ') t ';
+        $expectedSql .= 'ORDER BY DB_first_level ASC ';
+        $expectedSql .= 'LIMIT ' . $pos . ', ' . $limit;
+        $expectedSql .= ') t2 ';
         $expectedSql .= "WHERE TRUE AND 1 = LOCATE(CONCAT(DB_first_level, '_'), ";
         $expectedSql .= "CONCAT(SCHEMA_NAME, '_')) ";
-        $expectedSql .= "ORDER BY SCHEMA_NAME ASC";
+        $expectedSql .= 'ORDER BY SCHEMA_NAME ASC';
 
         // It would have been better to mock _getWhereClause method
         // but strangely, mocking private methods is not supported in PHPUnit
         $node = NodeFactory::getInstance();
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
@@ -396,11 +354,8 @@ class NodeTest extends PmaTestCase
     /**
      * Tests getData() method when DisableIS is false and navigation tree
      * grouping disabled.
-     *
-     * @return void
-     * @test
      */
-    public function testGetDataWithEnabledISAndGroupingDisabled()
+    public function testGetDataWithEnabledISAndGroupingDisabled(): void
     {
         $pos = 10;
         $limit = 20;
@@ -408,17 +363,17 @@ class NodeTest extends PmaTestCase
         $GLOBALS['cfg']['NavigationTreeEnableGrouping'] = false;
         $GLOBALS['cfg']['FirstLevelNavigationItems'] = $limit;
 
-        $expectedSql  = "SELECT `SCHEMA_NAME` ";
-        $expectedSql .= "FROM `INFORMATION_SCHEMA`.`SCHEMATA` ";
-        $expectedSql .= "WHERE TRUE ";
-        $expectedSql .= "ORDER BY `SCHEMA_NAME` ";
-        $expectedSql .= "LIMIT $pos, $limit";
+        $expectedSql  = 'SELECT `SCHEMA_NAME` ';
+        $expectedSql .= 'FROM `INFORMATION_SCHEMA`.`SCHEMATA` ';
+        $expectedSql .= 'WHERE TRUE ';
+        $expectedSql .= 'ORDER BY `SCHEMA_NAME` ';
+        $expectedSql .= 'LIMIT ' . $pos . ', ' . $limit;
 
         // It would have been better to mock _getWhereClause method
         // but strangely, mocking private methods is not supported in PHPUnit
         $node = NodeFactory::getInstance();
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
@@ -434,11 +389,8 @@ class NodeTest extends PmaTestCase
     /**
      * Tests getData() method when DisableIS is true and navigation tree
      * grouping enabled.
-     *
-     * @return void
-     * @test
      */
-    public function testGetDataWithDisabledISAndGroupingEnabled()
+    public function testGetDataWithDisabledISAndGroupingEnabled(): void
     {
         $pos = 0;
         $limit = 10;
@@ -450,7 +402,7 @@ class NodeTest extends PmaTestCase
 
         $node = NodeFactory::getInstance();
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
@@ -460,13 +412,9 @@ class NodeTest extends PmaTestCase
         $dbi->expects($this->exactly(3))
             ->method('fetchArray')
             ->willReturnOnConsecutiveCalls(
-                [
-                    '0' => 'db',
-                ],
-                [
-                    '0' => 'aa_db',
-                ],
-                false
+                ['0' => 'db'],
+                ['0' => 'aa_db'],
+                null
             );
 
         $dbi->expects($this->once())
@@ -486,29 +434,26 @@ class NodeTest extends PmaTestCase
     /**
      * Tests the getPresence method when DisableIS is false and navigation tree
      * grouping enabled.
-     *
-     * @return void
-     * @test
      */
-    public function testGetPresenceWithEnabledISAndGroupingEnabled()
+    public function testGetPresenceWithEnabledISAndGroupingEnabled(): void
     {
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['cfg']['NavigationTreeEnableGrouping'] = true;
         $GLOBALS['cfg']['NavigationTreeDbSeparator'] = '_';
 
-        $query = "SELECT COUNT(*) ";
-        $query .= "FROM ( ";
+        $query = 'SELECT COUNT(*) ';
+        $query .= 'FROM ( ';
         $query .= "SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, '_', 1) ";
-        $query .= "DB_first_level ";
-        $query .= "FROM INFORMATION_SCHEMA.SCHEMATA ";
-        $query .= "WHERE TRUE ";
-        $query .= ") t ";
+        $query .= 'DB_first_level ';
+        $query .= 'FROM INFORMATION_SCHEMA.SCHEMATA ';
+        $query .= 'WHERE TRUE ';
+        $query .= ') t ';
 
         // It would have been better to mock _getWhereClause method
         // but strangely, mocking private methods is not supported in PHPUnit
         $node = NodeFactory::getInstance();
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
@@ -521,21 +466,18 @@ class NodeTest extends PmaTestCase
     /**
      * Tests the getPresence method when DisableIS is false and navigation tree
      * grouping disabled.
-     *
-     * @return void
-     * @test
      */
-    public function testGetPresenceWithEnabledISAndGroupingDisabled()
+    public function testGetPresenceWithEnabledISAndGroupingDisabled(): void
     {
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['cfg']['NavigationTreeEnableGrouping'] = false;
 
-        $query = "SELECT COUNT(*) ";
-        $query .= "FROM INFORMATION_SCHEMA.SCHEMATA ";
-        $query .= "WHERE TRUE ";
+        $query = 'SELECT COUNT(*) ';
+        $query .= 'FROM INFORMATION_SCHEMA.SCHEMATA ';
+        $query .= 'WHERE TRUE ';
 
         $node = NodeFactory::getInstance();
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
@@ -547,11 +489,8 @@ class NodeTest extends PmaTestCase
 
     /**
      * Tests the getPresence method when DisableIS is true
-     *
-     * @return void
-     * @test
      */
-    public function testGetPresenceWithDisabledIS()
+    public function testGetPresenceWithDisabledIS(): void
     {
         $GLOBALS['cfg']['Server']['DisableIS'] = true;
         $GLOBALS['dbs_to_test'] = false;
@@ -560,12 +499,12 @@ class NodeTest extends PmaTestCase
         $node = NodeFactory::getInstance();
 
         // test with no search clause
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
             ->method('tryQuery')
-            ->with("SHOW DATABASES WHERE TRUE ");
+            ->with('SHOW DATABASES WHERE TRUE ');
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
@@ -573,7 +512,7 @@ class NodeTest extends PmaTestCase
         $node->getPresence();
 
         // test with a search clause
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->once())
