@@ -1,44 +1,34 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Normalization
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Message;
 use PhpMyAdmin\Normalization;
 use PhpMyAdmin\Relation;
 use PhpMyAdmin\Template;
-use PhpMyAdmin\Theme;
 use PhpMyAdmin\Transformations;
 use PhpMyAdmin\Types;
-use PhpMyAdmin\Util;
-use PHPUnit\Framework\TestCase;
-use ReflectionClass;
+use PhpMyAdmin\Url;
 use stdClass;
+use function json_encode;
 
-/**
- * tests for PhpMyAdmin\Normalization
- *
- * @package PhpMyAdmin-test
- */
-class NormalizationTest extends TestCase
+class NormalizationTest extends AbstractTestCase
 {
+    /** @var Normalization */
     private $normalization;
 
     /**
      * prepares environment for tests
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        parent::defineVersionConstants();
         $GLOBALS['cfg']['LimitChars'] = 50;
-        $GLOBALS['cfg']['ServerDefault'] = "PMA_server";
+        $GLOBALS['cfg']['ServerDefault'] = 'PMA_server';
         $GLOBALS['cfg']['ShowHint'] = true;
         $GLOBALS['cfg']['CharEditing'] = '';
         $GLOBALS['cfg']['ActionLinksMode'] = 'icons';
@@ -51,7 +41,7 @@ class NormalizationTest extends TestCase
         //$_SESSION
 
         //mock DBI
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->types = new Types($dbi);
@@ -65,15 +55,15 @@ class NormalizationTest extends TestCase
             ->will(
                 $this->returnValue(
                     [
-                        "id" => ["Type" => "integer"],
-                        "col1" => ["Type" => 'varchar(100)'],
-                        "col2" => ["Type" => 'DATETIME'],
+                        'id' => ['Type' => 'integer'],
+                        'col1' => ['Type' => 'varchar(100)'],
+                        'col2' => ['Type' => 'DATETIME'],
                     ]
                 )
             );
         $dbi->expects($this->any())
             ->method('getColumnNames')
-            ->will($this->returnValue(["id", "col1", "col2"]));
+            ->will($this->returnValue(['id', 'col1', 'col2']));
         $map = [
             [
                 'PMA_db',
@@ -124,13 +114,11 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlForColumnsList
-     *
-     * @return void
      */
-    public function testGetHtmlForColumnsList()
+    public function testGetHtmlForColumnsList(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $this->assertStringContainsString(
             '<option value="id">id [ integer ]</option>',
             $this->normalization->getHtmlForColumnsList($table, $db)
@@ -143,16 +131,14 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlForCreateNewColumn
-     *
-     * @return void
      */
-    public function testGetHtmlForCreateNewColumn()
+    public function testGetHtmlForCreateNewColumn(): void
     {
         $GLOBALS['cfg']['BrowseMIME'] = true;
         $GLOBALS['cfg']['MaxRows'] = 25;
         $GLOBALS['col_priv'] = false;
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $numFields = 1;
         $result = $this->normalization->getHtmlForCreateNewColumn($numFields, $db, $table);
         $this->assertStringContainsString(
@@ -163,25 +149,23 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlFor1NFStep1
-     *
-     * @return void
      */
-    public function testGetHtmlFor1NFStep1()
+    public function testGetHtmlFor1NFStep1(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $normalizedTo = '1nf';
         $result = $this->normalization->getHtmlFor1NFStep1($db, $table, $normalizedTo);
         $this->assertStringContainsString(
-            "<h3 class='center'>"
-            . __('First step of normalization (1NF)') . "</h3>",
+            "<h3 class='text-center'>"
+            . __('First step of normalization (1NF)') . '</h3>',
             $result
         );
         $this->assertStringContainsString(
             "<div id='mainContent'",
             $result
         );
-        $this->assertStringContainsString("<legend>" . __('Step 1.'), $result);
+        $this->assertStringContainsString('<legend>' . __('Step 1.'), $result);
 
         $this->assertStringContainsString(
             '<h4',
@@ -210,13 +194,11 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlContentsFor1NFStep2
-     *
-     * @return void
      */
-    public function testGetHtmlContentsFor1NFStep2()
+    public function testGetHtmlContentsFor1NFStep2(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table1";
+        $db = 'PMA_db';
+        $table = 'PMA_table1';
         $result = $this->normalization->getHtmlContentsFor1NFStep2($db, $table);
         $this->assertIsArray($result);
         $this->assertArrayHasKey('legendText', $result);
@@ -240,13 +222,11 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlContentsFor1NFStep4
-     *
-     * @return void
      */
-    public function testGetHtmlContentsFor1NFStep4()
+    public function testGetHtmlContentsFor1NFStep4(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $result = $this->normalization->getHtmlContentsFor1NFStep4($db, $table);
         $this->assertIsArray($result);
         $this->assertArrayHasKey('legendText', $result);
@@ -255,7 +235,7 @@ class NormalizationTest extends TestCase
         $this->assertArrayHasKey('extra', $result);
         $this->assertStringContainsString(__('Step 1.') . 4, $result['legendText']);
         $this->assertStringContainsString(
-            $this->normalization->getHtmlForColumnsList($db, $table, 'all', "checkbox"),
+            $this->normalization->getHtmlForColumnsList($db, $table, 'all', 'checkbox'),
             $result['extra']
         );
         $this->assertStringContainsString(
@@ -266,13 +246,11 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlContentsFor1NFStep3
-     *
-     * @return void
      */
-    public function testGetHtmlContentsFor1NFStep3()
+    public function testGetHtmlContentsFor1NFStep3(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $result = $this->normalization->getHtmlContentsFor1NFStep3($db, $table);
         $this->assertIsArray($result);
         $this->assertArrayHasKey('legendText', $result);
@@ -282,7 +260,7 @@ class NormalizationTest extends TestCase
         $this->assertArrayHasKey('primary_key', $result);
         $this->assertStringContainsString(__('Step 1.') . 3, $result['legendText']);
         $this->assertStringContainsString(
-            $this->normalization->getHtmlForColumnsList($db, $table, 'all', "checkbox"),
+            $this->normalization->getHtmlForColumnsList($db, $table, 'all', 'checkbox'),
             $result['extra']
         );
         $this->assertStringContainsString(
@@ -294,13 +272,11 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlFor2NFstep1
-     *
-     * @return void
      */
-    public function testGetHtmlFor2NFstep1()
+    public function testGetHtmlFor2NFstep1(): void
     {
-        $db = "PMA_db";
-        $table = "PMA_table";
+        $db = 'PMA_db';
+        $table = 'PMA_table';
         $result = $this->normalization->getHtmlFor2NFstep1($db, $table);
         $this->assertIsArray($result);
         $this->assertArrayHasKey('legendText', $result);
@@ -310,7 +286,7 @@ class NormalizationTest extends TestCase
         $this->assertArrayHasKey('primary_key', $result);
         $this->assertStringContainsString(__('Step 2.') . 1, $result['legendText']);
         $this->assertEquals('id', $result['primary_key']);
-        $result1 = $this->normalization->getHtmlFor2NFstep1($db, "PMA_table2");
+        $result1 = $this->normalization->getHtmlFor2NFstep1($db, 'PMA_table2');
         $this->assertEquals('id, col1', $result1['primary_key']);
         $this->assertStringContainsString(
             '<a href="#" id="showPossiblePd"',
@@ -324,12 +300,10 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlForNewTables2NF
-     *
-     * @return void
      */
-    public function testGetHtmlForNewTables2NF()
+    public function testGetHtmlForNewTables2NF(): void
     {
-        $table = "PMA_table";
+        $table = 'PMA_table';
         $partialDependencies = ['col1' => ['col2']];
         $result = $this->normalization->getHtmlForNewTables2NF($partialDependencies, $table);
         $this->assertStringContainsString(
@@ -340,12 +314,10 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for createNewTablesFor2NF
-     *
-     * @return void
      */
-    public function testCreateNewTablesFor2NF()
+    public function testCreateNewTablesFor2NF(): void
     {
-        $table = "PMA_table";
+        $table = 'PMA_table';
         $db = 'PMA_db';
         $tablesName = new stdClass();
         $tablesName->id = 'PMA_table';
@@ -378,12 +350,10 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlForNewTables3NF
-     *
-     * @return void
      */
-    public function testGetHtmlForNewTables3NF()
+    public function testGetHtmlForNewTables3NF(): void
     {
-        $tables = ["PMA_table" => ['col1']];
+        $tables = ['PMA_table' => ['col1']];
         $db = 'PMA_db';
         $dependencies = new stdClass();
         $dependencies->col1 = ['col2'];
@@ -397,7 +367,7 @@ class NormalizationTest extends TestCase
             $result
         );
         $tables = [
-            "PMA_table" => [
+            'PMA_table' => [
                 'col1',
                 'PMA_table',
             ],
@@ -431,22 +401,20 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for createNewTablesFor3NF
-     *
-     * @return void
      */
-    public function testCreateNewTablesFor3NF()
+    public function testCreateNewTablesFor3NF(): void
     {
         $db = 'PMA_db';
-        $cols = new stdClass();
-        $cols->pk = 'id';
-        $cols->nonpk = 'col1, col2';
-        $cols1 = new stdClass();
-        $cols1->pk = 'col2';
-        $cols1->nonpk = 'col3, col4';
         $newTables = [
             'PMA_table' => [
-                'PMA_table' => $cols,
-                'table1' => $cols1,
+                'PMA_table' => [
+                    'pk' => 'id',
+                    'nonpk' => 'col1, col2',
+                ],
+                'table1' => [
+                    'pk' => 'col2',
+                    'nonpk' => 'col3, col4',
+                ],
             ],
         ];
         $result = $this->normalization->createNewTablesFor3NF(
@@ -464,21 +432,19 @@ class NormalizationTest extends TestCase
         );
         $this->assertArrayHasKey('queryError', $result1);
         $this->assertEquals(__('End of step'), $result1['legendText']);
-        $this->assertEquals(false, $result1['queryError']);
+        $this->assertFalse($result1['queryError']);
     }
 
     /**
      * Test for moveRepeatingGroup
-     *
-     * @return void
      */
-    public function testMoveRepeatingGroup()
+    public function testMoveRepeatingGroup(): void
     {
         $repeatingColumns = 'col1, col2';
         $primaryColumns = 'id,col1';
         $newTable = 'PMA_newTable';
         $newColumn = 'PMA_newCol';
-        $table = "PMA_table";
+        $table = 'PMA_table';
         $db = 'PMA_db';
         $result = $this->normalization->moveRepeatingGroup(
             $repeatingColumns,
@@ -492,20 +458,18 @@ class NormalizationTest extends TestCase
         $this->assertArrayHasKey('queryError', $result);
         $this->assertArrayHasKey('message', $result);
         $this->assertInstanceOf(
-            'PhpMyAdmin\Message',
+            Message::class,
             $result['message']
         );
     }
 
     /**
      * Test for getHtmlFor3NFstep1
-     *
-     * @return void
      */
-    public function testGetHtmlFor3NFstep1()
+    public function testGetHtmlFor3NFstep1(): void
     {
-        $db = "PMA_db";
-        $tables = ["PMA_table"];
+        $db = 'PMA_db';
+        $tables = ['PMA_table'];
         $result = $this->normalization->getHtmlFor3NFstep1($db, $tables);
         $this->assertIsArray($result);
         $this->assertArrayHasKey('legendText', $result);
@@ -521,7 +485,7 @@ class NormalizationTest extends TestCase
             '<input type="checkbox" name="pd" value="col1"',
             $result['extra']
         );
-        $result1 = $this->normalization->getHtmlFor3NFstep1($db, ["PMA_table2"]);
+        $result1 = $this->normalization->getHtmlFor3NFstep1($db, ['PMA_table2']);
         $this->assertEquals(
             '',
             $result1['subText']
@@ -530,44 +494,32 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getHtmlForNormalizeTable
-     *
-     * @return void
      */
-    public function testgetHtmlForNormalizeTable()
+    public function testgetHtmlForNormalizeTable(): void
     {
         $result = $this->normalization->getHtmlForNormalizeTable();
         $this->assertStringContainsString(
-            '<form method="post" action="normalization.php"'
-            . ' name="normalize" id="normalizeTable"',
+            '<form method="post" action="' . Url::getFromRoute('/normalization')
+            . '" name="normalize" id="normalizeTable"',
             $result
         );
         $this->assertStringContainsString(
             '<input type="hidden" name="step1" value="1">',
             $result
         );
-        $choices = [
-            '1nf' => __('First step of normalization (1NF)'),
-            '2nf'      => __('Second step of normalization (1NF+2NF)'),
-            '3nf'  => __('Third step of normalization (1NF+2NF+3NF)'),
-        ];
 
-        $htmlTmp = Util::getRadioFields(
-            'normalizeTo',
-            $choices,
-            '1nf',
-            true
-        );
-        $this->assertStringContainsString($htmlTmp, $result);
+        $this->assertStringContainsString('type="radio" name="normalizeTo"', $result);
+        $this->assertStringContainsString('id="normalizeToRadio1" value="1nf" checked>', $result);
+        $this->assertStringContainsString('id="normalizeToRadio2" value="2nf">', $result);
+        $this->assertStringContainsString('id="normalizeToRadio3" value="3nf">', $result);
     }
 
     /**
      * Test for findPartialDependencies
-     *
-     * @return void
      */
-    public function testFindPartialDependencies()
+    public function testFindPartialDependencies(): void
     {
-        $table = "PMA_table2";
+        $table = 'PMA_table2';
         $db = 'PMA_db';
         $result = $this->normalization->findPartialDependencies($table, $db);
         $this->assertStringContainsString(
@@ -579,21 +531,21 @@ class NormalizationTest extends TestCase
 
     /**
      * Test for getAllCombinationPartialKeys
-     *
-     * @return void
      */
-    public function testGetAllCombinationPartialKeys()
+    public function testGetAllCombinationPartialKeys(): void
     {
-        $class = new ReflectionClass(Normalization::class);
-        $method = $class->getMethod('getAllCombinationPartialKeys');
-        $method->setAccessible(true);
-
         $primaryKey = [
             'id',
             'col1',
             'col2',
         ];
-        $result = $method->invokeArgs($this->normalization, [$primaryKey]);
+        $result = $this->callFunction(
+            $this->normalization,
+            Normalization::class,
+            'getAllCombinationPartialKeys',
+            [$primaryKey]
+        );
+
         $this->assertEquals(
             [
                 '',
