@@ -1,37 +1,38 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Plugins\Export\ExportYaml class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportYaml;
-use PhpMyAdmin\Tests\PmaTestCase;
+use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
+use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup;
+use PhpMyAdmin\Properties\Options\Items\HiddenPropertyItem;
+use PhpMyAdmin\Properties\Plugins\ExportPluginProperties;
+use PhpMyAdmin\Tests\AbstractTestCase;
 use ReflectionMethod;
 use ReflectionProperty;
+use stdClass;
+
+use function array_shift;
+use function ob_get_clean;
+use function ob_start;
 
 /**
- * tests for PhpMyAdmin\Plugins\Export\ExportYaml class
- *
- * @package PhpMyAdmin-test
  * @group medium
  */
-class ExportYamlTest extends PmaTestCase
+class ExportYamlTest extends AbstractTestCase
 {
+    /** @var ExportYaml */
     protected $object;
 
     /**
      * Configures global environment.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $GLOBALS['server'] = 0;
         $GLOBALS['output_kanji_conversion'] = false;
         $GLOBALS['buffer_needed'] = false;
@@ -44,31 +45,25 @@ class ExportYamlTest extends PmaTestCase
 
     /**
      * tearDown for test cases
-     *
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::setProperties
-     *
-     * @return void
-     */
-    public function testSetProperties()
+    public function testSetProperties(): void
     {
-        $method = new ReflectionMethod('PhpMyAdmin\Plugins\Export\ExportYaml', 'setProperties');
+        $method = new ReflectionMethod(ExportYaml::class, 'setProperties');
         $method->setAccessible(true);
         $method->invoke($this->object, null);
 
-        $attrProperties = new ReflectionProperty('PhpMyAdmin\Plugins\Export\ExportYaml', 'properties');
+        $attrProperties = new ReflectionProperty(ExportYaml::class, 'properties');
         $attrProperties->setAccessible(true);
         $properties = $attrProperties->getValue($this->object);
 
         $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Plugins\ExportPluginProperties',
+            ExportPluginProperties::class,
             $properties
         );
 
@@ -90,7 +85,7 @@ class ExportYamlTest extends PmaTestCase
         $options = $properties->getOptions();
 
         $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup',
+            OptionsPropertyRootGroup::class,
             $options
         );
 
@@ -104,7 +99,7 @@ class ExportYamlTest extends PmaTestCase
         $generalOptions = array_shift($generalOptionsArray);
 
         $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup',
+            OptionsPropertyMainGroup::class,
             $generalOptions
         );
 
@@ -118,17 +113,12 @@ class ExportYamlTest extends PmaTestCase
         $property = array_shift($generalProperties);
 
         $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Items\HiddenPropertyItem',
+            HiddenPropertyItem::class,
             $property
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportHeader
-     *
-     * @return void
-     */
-    public function testExportHeader()
+    public function testExportHeader(): void
     {
         ob_start();
         $this->assertTrue(
@@ -136,18 +126,15 @@ class ExportYamlTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
+        $this->assertIsString($result);
+
         $this->assertStringContainsString(
             "%YAML 1.1\n---\n",
             $result
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportFooter
-     *
-     * @return void
-     */
-    public function testExportFooter()
+    public function testExportFooter(): void
     {
         $this->expectOutputString(
             "...\n"
@@ -157,53 +144,55 @@ class ExportYamlTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportDBHeader
-     *
-     * @return void
-     */
-    public function testExportDBHeader()
+    public function testExportDBHeader(): void
     {
         $this->assertTrue(
             $this->object->exportDBHeader('&db')
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportDBFooter
-     *
-     * @return void
-     */
-    public function testExportDBFooter()
+    public function testExportDBFooter(): void
     {
         $this->assertTrue(
             $this->object->exportDBFooter('&db')
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportDBCreate
-     *
-     * @return void
-     */
-    public function testExportDBCreate()
+    public function testExportDBCreate(): void
     {
         $this->assertTrue(
             $this->object->exportDBCreate('testDB', 'database')
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportYaml::exportData
-     *
-     * @return void
-     */
-    public function testExportData()
+    public function testExportData(): void
     {
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
+        $flags = [];
+        $a = new stdClass();
+        $a->type = '';
+        $flags[] = $a;
+        $b = new stdClass();
+        $b->type = '';
+        $flags[] = $b;
+        $c = new stdClass();
+        $c->type = '';
+        $flags[] = $c;
+        $d = new stdClass();
+        $d->type = 'string';
+        $flags[] = $d;
+        $e = new stdClass();
+        $e->type = 'string';
+        $flags[] = $e;
+
+        $dbi->expects($this->once())
+            ->method('getFieldsMeta')
+            ->with(true)
+            ->will($this->returnValue($flags));
+
         $dbi->expects($this->once())
             ->method('query')
             ->with('SELECT', DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED)
@@ -212,44 +201,24 @@ class ExportYamlTest extends PmaTestCase
         $dbi->expects($this->once())
             ->method('numFields')
             ->with(true)
-            ->will($this->returnValue(4));
+            ->will($this->returnValue(5));
 
-        $dbi->expects($this->at(2))
+        $dbi->expects($this->exactly(5))
             ->method('fieldName')
-            ->will($this->returnValue('fName1'));
+            ->willReturn('fName1', 'fNa"me2', 'fNa\\me3', 'fName4', 'fName5');
 
-        $dbi->expects($this->at(3))
-            ->method('fieldName')
-            ->will($this->returnValue('fNa"me2'));
-
-        $dbi->expects($this->at(4))
-            ->method('fieldName')
-            ->will($this->returnValue('fNa\\me3'));
-
-        $dbi->expects($this->at(5))
-            ->method('fieldName')
-            ->will($this->returnValue('fName4'));
-
-        $dbi->expects($this->at(6))
+        $dbi->expects($this->exactly(3))
             ->method('fetchRow')
-            ->with(true)
-            ->will(
-                $this->returnValue(
-                    [
-                        null,
-                        '123',
-                        "\"c\\a\nb\r",
-                    ]
-                )
-            );
-
-        $dbi->expects($this->at(7))
-            ->method('fetchRow')
-            ->with(true)
-            ->will(
-                $this->returnValue(
-                    [null]
-                )
+            ->willReturn(
+                [
+                    null,
+                    '123',
+                    "\"c\\a\nb\r",
+                    '123',
+                    '+30.2103210000',
+                ],
+                [null],
+                null
             );
 
         $GLOBALS['dbi'] = $dbi;
@@ -260,8 +229,8 @@ class ExportYamlTest extends PmaTestCase
                 'db',
                 'ta<ble',
                 "\n",
-                "example.com",
-                "SELECT"
+                'example.com',
+                'SELECT'
             )
         );
         $result = ob_get_clean();
@@ -271,6 +240,8 @@ class ExportYamlTest extends PmaTestCase
             '-' . "\n" .
             '  fNa&quot;me2: 123' . "\n" .
             '  fName3: &quot;\&quot;c\\\\a\nb\r&quot;' . "\n" .
+            '  fName4: &quot;123&quot;' . "\n" .
+            '  fName5: &quot;+30.2103210000&quot;' . "\n" .
             '-' . "\n",
             $result
         );
