@@ -1,52 +1,36 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Properties\Options\Groups;
 
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup;
-use PHPUnit\Framework\TestCase;
+use PhpMyAdmin\Tests\AbstractTestCase;
 
-/**
- * tests for PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup class
- *
- * @package PhpMyAdmin-test
- */
-class OptionsPropertySubgroupTest extends TestCase
+class OptionsPropertySubgroupTest extends AbstractTestCase
 {
+    /** @var OptionsPropertySubgroup */
     protected $object;
 
     /**
      * Configures global environment.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $this->object = new OptionsPropertySubgroup();
     }
 
     /**
      * tearDown for test cases
-     *
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
-    /**
-     * Test for PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup::getItemType
-     *
-     * @return void
-     */
-    public function testGetItemType()
+    public function testGetItemType(): void
     {
         $this->assertEquals(
             'subgroup',
@@ -58,10 +42,8 @@ class OptionsPropertySubgroupTest extends TestCase
      * Test for
      *     - PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup::getSubgroupHeader
      *     - PhpMyAdmin\Properties\Options\Groups\OptionsPropertySubgroup::setSubgroupHeader
-     *
-     * @return void
      */
-    public function testGetSetSubgroupHeader()
+    public function testGetSetSubgroupHeader(): void
     {
         $this->object->setSubgroupHeader('subGroupHeader123');
 
