@@ -1,37 +1,26 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Tests for PhpMyAdmin\Tracker
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Tests\PmaTestCase;
 use PhpMyAdmin\Tracker;
 use PhpMyAdmin\Util;
-use ReflectionClass;
 use ReflectionMethod;
 use ReflectionProperty;
 
-/**
- * Tests for PhpMyAdmin\Tracker
- *
- * @package PhpMyAdmin-test
- */
-class TrackerTest extends PmaTestCase
+class TrackerTest extends AbstractTestCase
 {
     /**
      * Setup function for test cases
      *
      * @access protected
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
+        parent::defineVersionConstants();
         /**
          * SET these to avoid undefined index error
          */
@@ -49,21 +38,17 @@ class TrackerTest extends PmaTestCase
             'tracking' => 'tracking',
         ];
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
-
-        $cfg['dbi'] = $dbi;
     }
+
     /**
      * Test for Tracker::enable
-     *
-     * @return void
-     * @test
      */
-    public function testEnabled()
+    public function testEnabled(): void
     {
         $reflection = new ReflectionProperty(Tracker::class, 'enabled');
         $reflection->setAccessible(true);
@@ -76,13 +61,10 @@ class TrackerTest extends PmaTestCase
 
     /**
      * Test for Tracker::isActive()
-     *
-     * @return void
-     * @test
      */
-    public function testIsActive()
+    public function testIsActive(): void
     {
-        $attr = new ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
+        $attr = new ReflectionProperty(Tracker::class, 'enabled');
         $attr->setAccessible(true);
         $attr->setValue(false);
 
@@ -119,19 +101,13 @@ class TrackerTest extends PmaTestCase
      * @param string $string   String to test against
      * @param string $expected Expected Table Name
      *
-     * @return void
-     * @test
      * @dataProvider getTableNameData
      */
-    public function testGetTableName($string, $expected): void
+    public function testGetTableName(string $string, string $expected): void
     {
-        $reflection = new ReflectionClass('PhpMyAdmin\Tracker');
-        $method = $reflection->getMethod("getTableName");
-        $method->setAccessible(true);
-
         $this->assertEquals(
             $expected,
-            $method->invokeArgs(null, [$string])
+            $this->callFunction(null, Tracker::class, 'getTableName', [$string])
         );
     }
 
@@ -139,40 +115,36 @@ class TrackerTest extends PmaTestCase
      * Data Provider for testGetTableName
      *
      * @return array Test data
-     *
      */
-    public function getTableNameData()
+    public function getTableNameData(): array
     {
         return [
             [
-                "`tbl`;",
-                "tbl",
+                '`tbl`;',
+                'tbl',
             ],
             [
-                " `pma.table` ",
-                "table",
+                ' `pma.table` ',
+                'table',
             ],
             [
                 " `pma.table\nfoobar` ",
-                "table",
+                'table',
             ],
         ];
     }
 
     /**
      * Test for Tracker::isTracked()
-     *
-     * @return void
-     * @test
      */
-    public function testIsTracked()
+    public function testIsTracked(): void
     {
-        $attr = new ReflectionProperty('PhpMyAdmin\Tracker', 'enabled');
+        $attr = new ReflectionProperty(Tracker::class, 'enabled');
         $attr->setAccessible(true);
         $attr->setValue(false);
 
         $this->assertFalse(
-            Tracker::isTracked("", "")
+            Tracker::isTracked('', '')
         );
 
         Tracker::enable();
@@ -181,50 +153,44 @@ class TrackerTest extends PmaTestCase
         $_SESSION['relation'][$GLOBALS['server']]['trackingwork'] = false;
 
         $this->assertFalse(
-            Tracker::isTracked("", "")
+            Tracker::isTracked('', '')
         );
 
         $_SESSION['relation'][$GLOBALS['server']]['trackingwork'] = true;
 
         $this->assertTrue(
-            Tracker::isTracked("pma_test_db", "pma_test_table")
+            Tracker::isTracked('pma_test_db', 'pma_test_table')
         );
 
         $this->assertFalse(
-            Tracker::isTracked("pma_test_db", "pma_test_table2")
+            Tracker::isTracked('pma_test_db', 'pma_test_table2')
         );
     }
 
     /**
      * Test for Tracker::getLogComment()
-     *
-     * @return void
-     * @test
      */
-    public function testGetLogComment()
+    public function testGetLogComment(): void
     {
         $date = Util::date('Y-m-d H:i:s');
-        $GLOBALS['cfg']['Server']['user'] = "pma_test_user";
+        $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
         $this->assertEquals(
-            "# log $date pma_test_user\n",
+            '# log ' . $date . " pma_test_user\n",
             Tracker::getLogComment()
         );
     }
 
     /**
      * Test for Tracker::createVersion()
-     *
-     * @return void
-     * @test
      */
-    public function testCreateVersion()
+    public function testCreateVersion(): void
     {
         $GLOBALS['cfg']['Server']['tracking_add_drop_table'] = true;
         $GLOBALS['cfg']['Server']['tracking_add_drop_view'] = true;
-        $GLOBALS['cfg']['Server']['user'] = "pma_test_user";
+        $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -276,7 +242,7 @@ class TrackerTest extends PmaTestCase
 
         $date = Util::date('Y-m-d H:i:s');
 
-        $expectedMainQuery = "/*NOTRACK*/" .
+        $expectedMainQuery = '/*NOTRACK*/' .
         "\nINSERT INTO `pmadb`.`tracking` (db_name, table_name, version, date_created, date_updated," .
         " schema_snapshot, schema_sql, data_sql, tracking ) values (
         'pma_test',
@@ -285,16 +251,16 @@ class TrackerTest extends PmaTestCase
         '" . $date . "',
         '" . $date . "',
         'a:2:{s:7:\"COLUMNS\";a:2:{" .
-        "i:0;a:3:{s:5:\"Field\";s:6:\"field1\";s:4:\"Type\";s:7:\"int(11)\";" .
-        "s:3:\"Key\";s:3:\"PRI\";}" .
-        "i:1;a:3:{s:5:\"Field\";s:6:\"field2\";s:4:\"Type\";s:4:\"text\";" .
-        "s:3:\"Key\";s:0:\"\";}}" .
-        "s:7:\"INDEXES\";a:1:{" .
-        "i:0;a:3:{s:5:\"Table\";s:7:\"pma_tbl\";s:5:\"Field\";s:6:\"field1\";" .
+        'i:0;a:3:{s:5:"Field";s:6:"field1";s:4:"Type";s:7:"int(11)";' .
+        's:3:"Key";s:3:"PRI";}' .
+        'i:1;a:3:{s:5:"Field";s:6:"field2";s:4:"Type";s:4:"text";' .
+        's:3:"Key";s:0:"";}}' .
+        's:7:"INDEXES";a:1:{' .
+        'i:0;a:3:{s:5:"Table";s:7:"pma_tbl";s:5:"Field";s:6:"field1";' .
         "s:3:\"Key\";s:7:\"PRIMARY\";}}}',
-        '# log " . $date . " pma_test_user" .
+        '# log " . $date . ' pma_test_user' .
         "\nDROP VIEW IF EXISTS `pma_tbl`;" .
-        "\n# log " . $date . " pma_test_user" .
+        "\n# log " . $date . ' pma_test_user' .
         "\n\n;" .
         "\n',
         '" .
@@ -328,18 +294,15 @@ class TrackerTest extends PmaTestCase
 
     /**
      * Test for Tracker::deleteTracking()
-     *
-     * @return void
-     * @test
      */
-    public function testDeleteTracking()
+    public function testDeleteTracking(): void
     {
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
         $sql_query = "/*NOTRACK*/\n"
-            . "DELETE FROM `pmadb`.`tracking`"
+            . 'DELETE FROM `pmadb`.`tracking`'
             . " WHERE `db_name` = 'testdb'"
             . " AND `table_name` = 'testtable'";
 
@@ -352,30 +315,27 @@ class TrackerTest extends PmaTestCase
 
         $GLOBALS['dbi'] = $dbi;
         $this->assertEquals(
-            Tracker::deleteTracking("testdb", "testtable"),
+            Tracker::deleteTracking('testdb', 'testtable'),
             'executed'
         );
     }
 
     /**
      * Test for Tracker::createDatabaseVersion()
-     *
-     * @return void
-     * @test
      */
-    public function testCreateDatabaseVersion()
+    public function testCreateDatabaseVersion(): void
     {
         $GLOBALS['cfg']['Server']['tracking_add_drop_table'] = true;
         $GLOBALS['cfg']['Server']['tracking_add_drop_view'] = true;
-        $GLOBALS['cfg']['Server']['user'] = "pma_test_user";
+        $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
         $date = Util::date('Y-m-d H:i:s');
 
-        $expectedMainQuery = "/*NOTRACK*/" .
+        $expectedMainQuery = '/*NOTRACK*/' .
         "\nINSERT INTO `pmadb`.`tracking` (db_name, table_name, version, date_created, date_updated," .
         " schema_snapshot, schema_sql, data_sql, tracking ) values (
         'pma_test',
@@ -384,7 +344,7 @@ class TrackerTest extends PmaTestCase
         '" . $date . "',
         '" . $date . "',
         '',
-        '# log " . $date . " pma_test_user" .
+        '# log " . $date . ' pma_test_user' .
         "\nSHOW DATABASES',
         '" .
         "\n',
@@ -393,7 +353,7 @@ class TrackerTest extends PmaTestCase
         $dbi->expects($this->exactly(1))
             ->method('query')
             ->with($expectedMainQuery, DatabaseInterface::CONNECT_CONTROL, 0, false)
-            ->will($this->returnValue("executed"));
+            ->will($this->returnValue('executed'));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
@@ -409,29 +369,24 @@ class TrackerTest extends PmaTestCase
      * Test for Tracker::changeTracking(). This test is also invoked by two
      * other tests: testActivateTracking() and testDeactivateTracking()
      *
-     * @param string $dbname    Database name
-     * @param string $tablename Table name
-     * @param string $version   Version
-     * @param string $new_state State to change to
-     * @param string $type      Type of test
-     *
-     * @return void
-     *
-     * @test
-     *
+     * @param string     $dbname    Database name
+     * @param string     $tablename Table name
+     * @param string     $version   Version
+     * @param string|int $new_state State to change to
+     * @param string     $type      Type of test
      */
     public function testChangeTracking(
-        $dbname = 'pma_db',
-        $tablename = 'pma_tbl',
-        $version = '0.1',
+        string $dbname = 'pma_db',
+        string $tablename = 'pma_tbl',
+        string $version = '0.1',
         $new_state = '1',
-        $type = null
-    ) {
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        ?string $type = null
+    ): void {
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
-        $sql_query = " UPDATE `pmadb`.`tracking` SET `tracking_active` = " .
+        $sql_query = ' UPDATE `pmadb`.`tracking` SET `tracking_active` = ' .
         "'" . $new_state . "' " .
         " WHERE `db_name` = '" . $dbname . "' " .
         " AND `table_name` = '" . $tablename . "' " .
@@ -440,7 +395,7 @@ class TrackerTest extends PmaTestCase
         $dbi->expects($this->exactly(1))
             ->method('query')
             ->with($sql_query, DatabaseInterface::CONNECT_CONTROL, 0, false)
-            ->will($this->returnValue("executed"));
+            ->will($this->returnValue('executed'));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
@@ -450,7 +405,7 @@ class TrackerTest extends PmaTestCase
         $result = null;
 
         if ($type === null) {
-            $method = new ReflectionMethod('PhpMyAdmin\Tracker', '_changeTracking');
+            $method = new ReflectionMethod(Tracker::class, 'changeTracking');
             $method->setAccessible(true);
             $result = $method->invoke(
                 null,
@@ -459,9 +414,9 @@ class TrackerTest extends PmaTestCase
                 $version,
                 $new_state
             );
-        } elseif ($type == "activate") {
+        } elseif ($type === 'activate') {
             $result = Tracker::activateTracking($dbname, $tablename, $version);
-        } elseif ($type == "deactivate") {
+        } elseif ($type === 'deactivate') {
             $result = Tracker::deactivateTracking($dbname, $tablename, $version);
         }
 
@@ -473,21 +428,18 @@ class TrackerTest extends PmaTestCase
 
     /**
      * Test for Tracker::testChangeTrackingData()
-     *
-     * @return void
-     * @test
      */
-    public function testChangeTrackingData()
+    public function testChangeTrackingData(): void
     {
         $this->assertFalse(
-            Tracker::changeTrackingData("", "", "", "", "")
+            Tracker::changeTrackingData('', '', '', '', '')
         );
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
-        $sql_query_1 = " UPDATE `pmadb`.`tracking`" .
+        $sql_query_1 = ' UPDATE `pmadb`.`tracking`' .
         " SET `schema_sql` = '# new_data_processed' " .
         " WHERE `db_name` = 'pma_db' " .
         " AND `table_name` = 'pma_table' " .
@@ -506,9 +458,9 @@ class TrackerTest extends PmaTestCase
             ],
         ];
 
-        $sql_query_2 = " UPDATE `pmadb`.`tracking`" .
-        " SET `data_sql` = '# log $date user1test_statement1\n" .
-        "# log $date user2test_statement2\n' " .
+        $sql_query_2 = ' UPDATE `pmadb`.`tracking`' .
+        " SET `data_sql` = '# log " . $date . " user1test_statement1\n" .
+        '# log ' . $date . " user2test_statement2\n' " .
         " WHERE `db_name` = 'pma_db' " .
         " AND `table_name` = 'pma_table' " .
         " AND `version` = '1.0' ";
@@ -522,14 +474,14 @@ class TrackerTest extends PmaTestCase
                             DatabaseInterface::CONNECT_CONTROL,
                             0,
                             false,
-                            "executed_1",
+                            'executed_1',
                         ],
                         [
                             $sql_query_2,
                             DatabaseInterface::CONNECT_CONTROL,
                             0,
                             false,
-                            "executed_2",
+                            'executed_2',
                         ],
                     ]
                 )
@@ -540,19 +492,17 @@ class TrackerTest extends PmaTestCase
 
         $GLOBALS['dbi'] = $dbi;
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             Tracker::changeTrackingData(
                 'pma_db',
                 'pma_table',
                 '1.0',
                 'DDL',
-                "# new_data_processed"
+                '# new_data_processed'
             )
         );
 
-        $this->assertEquals(
-            true,
+        $this->assertTrue(
             Tracker::changeTrackingData(
                 'pma_db',
                 'pma_table',
@@ -565,22 +515,16 @@ class TrackerTest extends PmaTestCase
 
     /**
      * Test for Tracker::activateTracking()
-     *
-     * @return void
-     * @test
      */
-    public function testActivateTracking()
+    public function testActivateTracking(): void
     {
         $this->testChangeTracking('pma_db', 'pma_tbl', '0.1', 1, 'activate');
     }
 
     /**
      * Test for Tracker::deactivateTracking()
-     *
-     * @return void
-     * @test
      */
-    public function testDeactivateTracking()
+    public function testDeactivateTracking(): void
     {
         $this->testChangeTracking('pma_db', 'pma_tbl', '0.1', '0', 'deactivate');
     }
@@ -591,23 +535,21 @@ class TrackerTest extends PmaTestCase
      * @param array $fetchArrayReturn Value to be returned by mocked fetchArray
      * @param array $expectedArray    Expected array
      *
-     * @return void
-     * @test
      * @dataProvider getTrackedDataProvider
      */
-    public function testGetTrackedData($fetchArrayReturn, $expectedArray): void
+    public function testGetTrackedData(array $fetchArrayReturn, array $expectedArray): void
     {
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
         $dbi->expects($this->once())
             ->method('query')
-            ->will($this->returnValue("executed_1"));
+            ->will($this->returnValue('executed_1'));
 
         $dbi->expects($this->once())
             ->method('fetchAssoc')
-            ->with("executed_1")
+            ->with('executed_1')
             ->will($this->returnValue($fetchArrayReturn));
 
         $dbi->expects($this->any())
@@ -624,15 +566,15 @@ class TrackerTest extends PmaTestCase
                             "pma\'table",
                         ],
                         [
-                            "1.0",
-                            "1.0",
+                            '1.0',
+                            '1.0',
                         ],
                     ]
                 )
             );
 
         $GLOBALS['dbi'] = $dbi;
-        $result = Tracker::getTrackedData("pma'db", "pma'table", "1.0");
+        $result = Tracker::getTrackedData("pma'db", "pma'table", '1.0');
 
         $this->assertEquals(
             $expectedArray,
@@ -645,15 +587,15 @@ class TrackerTest extends PmaTestCase
      *
      * @return array Test data
      */
-    public function getTrackedDataProvider()
+    public function getTrackedDataProvider(): array
     {
         $fetchArrayReturn = [
             [
-                "schema_sql" => "# log 20-03-2013 23:33:58 user1\nstat1" .
+                'schema_sql' => "# log 20-03-2013 23:33:58 user1\nstat1" .
                 "# log 20-03-2013 23:39:58 user2\n",
-                "data_sql" => "# log ",
-                "schema_snapshot" => "dataschema",
-                "tracking" => "SELECT, DELETE",
+                'data_sql' => '# log ',
+                'schema_snapshot' => 'dataschema',
+                'tracking' => 'SELECT, DELETE',
             ],
         ];
 
@@ -670,22 +612,22 @@ class TrackerTest extends PmaTestCase
                     [
                         'date' => '20-03-2013 23:39:58',
                         'username' => 'user2',
-                        'statement' => "",
+                        'statement' => '',
                     ],
                 ],
                 'dmlog' => [],
-                "schema_snapshot" => "dataschema",
-                "tracking" => "SELECT, DELETE",
+                'schema_snapshot' => 'dataschema',
+                'tracking' => 'SELECT, DELETE',
             ],
         ];
 
         $fetchArrayReturn[1] = [
-            "schema_sql" => "# log 20-03-2012 23:33:58 user1\n" .
+            'schema_sql' => "# log 20-03-2012 23:33:58 user1\n" .
             "# log 20-03-2012 23:39:58 user2\n",
-            "data_sql" => "# log 20-03-2013 23:33:58 user3\n" .
+            'data_sql' => "# log 20-03-2013 23:33:58 user3\n" .
             "# log 20-03-2013 23:39:58 user4\n",
-            "schema_snapshot" => "dataschema",
-            "tracking" => "SELECT, DELETE",
+            'schema_snapshot' => 'dataschema',
+            'tracking' => 'SELECT, DELETE',
         ];
 
         $data[1] = [
@@ -695,29 +637,30 @@ class TrackerTest extends PmaTestCase
                 [
                     'date' => '20-03-2012 23:33:58',
                     'username' => 'user1',
-                    'statement' => "",
+                    'statement' => '',
                 ],
                 [
                     'date' => '20-03-2012 23:39:58',
                     'username' => 'user2',
-                    'statement' => "",
+                    'statement' => '',
                 ],
             ],
             'dmlog' => [
                 [
                     'date' => '20-03-2013 23:33:58',
                     'username' => 'user3',
-                    'statement' => "",
+                    'statement' => '',
                 ],
                 [
                     'date' => '20-03-2013 23:39:58',
                     'username' => 'user4',
-                    'statement' => "",
+                    'statement' => '',
                 ],
             ],
-            "schema_snapshot" => "dataschema",
-            "tracking" => "SELECT, DELETE",
+            'schema_snapshot' => 'dataschema',
+            'tracking' => 'SELECT, DELETE',
         ];
+
         return [
             [
                 $fetchArrayReturn[0],
@@ -733,26 +676,23 @@ class TrackerTest extends PmaTestCase
     /**
      * Test for Tracker::parseQuery
      *
-     * @param string $query                  Query to parse
-     * @param string $type                   Expected type
-     * @param string $identifier             Expected identifier
-     * @param string $tablename              Expected tablename
-     * @param string $db                     Expected dbname
-     * @param string $tablename_after_rename Expected name after rename
+     * @param string      $query                  Query to parse
+     * @param string      $type                   Expected type
+     * @param string      $identifier             Expected identifier
+     * @param string|null $tablename              Expected tablename
+     * @param string|null $db                     Expected dbname
+     * @param string|null $tablename_after_rename Expected name after rename
      *
-     * @return void
-     *
-     * @test
      * @dataProvider parseQueryData
      */
     public function testParseQuery(
-        $query,
-        $type,
-        $identifier,
-        $tablename,
-        $db = null,
-        $tablename_after_rename = null
-    ) {
+        string $query,
+        string $type,
+        string $identifier,
+        ?string $tablename,
+        ?string $db = null,
+        ?string $tablename_after_rename = null
+    ): void {
         $result = Tracker::parseQuery($query);
 
         $this->assertEquals(
@@ -777,12 +717,14 @@ class TrackerTest extends PmaTestCase
             );
         }
 
-        if ($tablename_after_rename) {
-            $this->assertEquals(
-                $result['tablename_after_rename'],
-                $tablename_after_rename
-            );
+        if (! $tablename_after_rename) {
+            return;
         }
+
+        $this->assertEquals(
+            $result['tablename_after_rename'],
+            $tablename_after_rename
+        );
     }
 
     /**
@@ -790,8 +732,14 @@ class TrackerTest extends PmaTestCase
      *
      * @return array Test data
      */
-    public function parseQueryData()
+    public function parseQueryData(): array
     {
+        // query
+        // type
+        // identifier
+        // table name
+        // db (optional)
+        // table name after rename (optional)
         $query = [];
         /** TODO: Should test fail when USE is in conjunction with * identifiers?
         $query[] = array(
@@ -803,128 +751,144 @@ class TrackerTest extends PmaTestCase
         );
         */
         $query[] = [
-            "CREATE VIEW v AS SELECT * FROM t;",
-            "DDL",
-            "CREATE VIEW",
-            "v",
+            'CREATE VIEW v AS SELECT * FROM t;',
+            'DDL',
+            'CREATE VIEW',
+            'v',
         ];
         $query[] = [
-            "ALTER VIEW db1.v AS SELECT col1, col2, col3, col4 FROM t",
-            "DDL",
-            "ALTER VIEW",
-            "v",
+            'ALTER VIEW db1.v AS SELECT col1, col2, col3, col4 FROM t',
+            'DDL',
+            'ALTER VIEW',
+            'v',
         ];
         $query[] = [
-            "DROP VIEW db1.v;",
-            "DDL",
-            "DROP VIEW",
-            "v",
+            'DROP VIEW db1.v;',
+            'DDL',
+            'DROP VIEW',
+            'v',
         ];
         $query[] = [
-            "DROP VIEW IF EXISTS db1.v;",
-            "DDL",
-            "DROP VIEW",
-            "v",
+            'DROP VIEW IF EXISTS db1.v;',
+            'DDL',
+            'DROP VIEW',
+            'v',
         ];
         $query[] = [
-            "CREATE DATABASE db1;",
-            "DDL",
-            "CREATE DATABASE",
-            "",
-            "db1",
+            'CREATE DATABASE db1;',
+            'DDL',
+            'CREATE DATABASE',
+            '',
+            'db1',
         ];
         $query[] = [
-            "ALTER DATABASE db1;",
-            "DDL",
-            "ALTER DATABASE",
-            "",
+            'ALTER DATABASE db1;',
+            'DDL',
+            'ALTER DATABASE',
+            '',
         ];
         $query[] = [
-            "DROP DATABASE db1;",
-            "DDL",
-            "DROP DATABASE",
-            "",
-            "db1",
+            'DROP DATABASE db1;',
+            'DDL',
+            'DROP DATABASE',
+            '',
+            'db1',
         ];
         $query[] = [
-            "CREATE TABLE db1.t1 (c1 INT);",
-            "DDL",
-            "CREATE TABLE",
-            "t1",
+            'CREATE TABLE db1.t1 (c1 INT);',
+            'DDL',
+            'CREATE TABLE',
+            't1',
         ];
         $query[] =  [
-            "ALTER TABLE db1.t1 ADD c2 TEXT;",
-            "DDL",
-            "ALTER TABLE",
-            "t1",
+            'ALTER TABLE db1.t1 ADD c2 TEXT;',
+            'DDL',
+            'ALTER TABLE',
+            't1',
         ];
         $query[] =  [
-            "DROP TABLE db1.t1",
-            "DDL",
-            "DROP TABLE",
-            "t1",
+            'DROP TABLE db1.t1',
+            'DDL',
+            'DROP TABLE',
+            't1',
         ];
         $query[] =  [
-            "DROP TABLE IF EXISTS db1.t1",
-            "DDL",
-            "DROP TABLE",
-            "t1",
+            'DROP TABLE IF EXISTS db1.t1',
+            'DDL',
+            'DROP TABLE',
+            't1',
         ];
         $query[] =  [
-            "CREATE INDEX ind ON db1.t1 (c2(10));",
-            "DDL",
-            "CREATE INDEX",
-            "t1",
+            'CREATE INDEX ind ON db1.t1 (c2(10));',
+            'DDL',
+            'CREATE INDEX',
+            't1',
         ];
         $query[] =  [
-            "CREATE UNIQUE INDEX ind ON db1.t1 (c2(10));",
-            "DDL",
-            "CREATE INDEX",
-            "t1",
+            'CREATE UNIQUE INDEX ind ON db1.t1 (c2(10));',
+            'DDL',
+            'CREATE INDEX',
+            't1',
         ];
         $query[] =  [
-            "CREATE SPATIAL INDEX ind ON db1.t1 (c2(10));",
-            "DDL",
-            "CREATE INDEX",
-            "t1",
+            'CREATE SPATIAL INDEX ind ON db1.t1 (c2(10));',
+            'DDL',
+            'CREATE INDEX',
+            't1',
         ];
         $query[] =  [
-            "DROP INDEX ind ON db1.t1;",
-            "DDL",
-            "DROP INDEX",
-            "t1",
+            'DROP INDEX ind ON db1.t1;',
+            'DDL',
+            'DROP INDEX',
+            't1',
         ];
         $query[] =  [
-            "RENAME TABLE db1.t1 TO db1.t2",
-            "DDL",
-            "RENAME TABLE",
-            "t1",
-            "",
-            "t2",
+            'RENAME TABLE db1.t1 TO db1.t2',
+            'DDL',
+            'RENAME TABLE',
+            't1',
+            '',
+            't2',
         ];
         $query[] =  [
-            "UPDATE db1.t1 SET a = 2",
-            "DML",
-            "UPDATE",
-            "t1",
+            'UPDATE db1.t1 SET a = 2',
+            'DML',
+            'UPDATE',
+            't1',
         ];
         $query[] =  [
-            "INSERT INTO db1.t1 (a, b, c) VALUES(1, 2, 3)",
-            "DML",
-            "INSERT",
-            "t1",
+            'INSERT INTO db1.t1 (a, b, c) VALUES(1, 2, 3)',
+            'DML',
+            'INSERT',
+            't1',
         ];
         $query[] =  [
-            "DELETE FROM db1.t1",
-            "DML",
-            "DELETE",
-            "t1",
+            'DELETE FROM db1.t1',
+            'DML',
+            'DELETE',
+            't1',
         ];
         $query[] =  [
-            "TRUNCATE db1.t1",
-            "DML",
-            "TRUNCATE",
-            "t1",
+            'TRUNCATE db1.t1',
+            'DML',
+            'TRUNCATE',
+            't1',
+        ];
+        $query[] = [
+            'create table event(' . "\n"
+            . 'eventID varchar(10) not null,' . "\n"
+            . 'b char(30),' . "\n"
+            . 'c varchar(20),' . "\n"
+            . 'd TIME,' . "\n"
+            . 'e Date,' . "\n"
+            . 'f int,' . "\n"
+            . 'g char(70),' . "\n"
+            . 'h char(90),' . "\n"
+            . 'primary key(eventID)' . "\n"
+            . ')' . "\n",
+            'DDL',
+            'CREATE TABLE',
+            null,// switch this to 'event' when sql-parse is fixed
         ];
 
         return $query;
