@@ -1,11 +1,8 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Selenium TestCase for user related tests
- *
- * @package    PhpMyAdmin-test
- * @subpackage Selenium
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Selenium;
@@ -13,19 +10,24 @@ namespace PhpMyAdmin\Tests\Selenium;
 /**
  * CreateRemoveUserTest class
  *
- * @package    PhpMyAdmin-test
- * @subpackage Selenium
  * @group      selenium
  */
 class CreateRemoveUserTest extends TestBase
 {
+    /**
+     * Create a test database for this test class
+     *
+     * @var bool
+     */
+    protected static $createDatabase = false;
+
     /**
      * Username for the user
      *
      * @access private
      * @var string
      */
-    private $_txtUsername;
+    private $txtUsername;
 
     /**
      * Password for the user
@@ -33,58 +35,54 @@ class CreateRemoveUserTest extends TestBase
      * @access private
      * @var string
      */
-    private $_txtPassword;
+    private $txtPassword;
 
     /**
      * Setup the browser environment to run the selenium test case
-     *
-     * @return void
      */
     protected function setUp(): void
     {
         parent::setUp();
         $this->skipIfNotSuperUser();
-        $this->_txtUsername = 'pma_user';
-        $this->_txtPassword = 'abc_123';
+        $this->txtUsername = 'pma_user';
+        $this->txtPassword = 'abc_123';
         $this->login();
     }
 
     /**
      * Creates and removes a user
      *
-     * @return void
-     *
      * @group large
      */
-    public function testCreateRemoveUser()
+    public function testCreateRemoveUser(): void
     {
-        $this->waitForElement('partialLinkText', "User accounts")->click();
+        $this->waitForElement('partialLinkText', 'User accounts')->click();
 
         // Let the User Accounts page load
         $this->waitAjax();
 
         $this->scrollIntoView('add_user_anchor');
         $this->waitForElement('id', 'usersForm');
-        $ele = $this->waitForElement('id', "add_user_anchor");
+        $ele = $this->waitForElement('id', 'add_user_anchor');
         $this->moveto($ele);
         $ele->click();
 
         $this->waitAjax();
-        $userField = $this->waitForElement('name', "username");
-        $userField->sendKeys($this->_txtUsername);
+        $userField = $this->waitForElement('name', 'username');
+        $userField->sendKeys($this->txtUsername);
 
-        $this->selectByLabel($this->byId("select_pred_hostname"), 'Local');
+        $this->selectByLabel($this->byId('select_pred_hostname'), 'Local');
 
         $this->scrollIntoView('button_generate_password');
         $genButton = $this->waitForElement('id', 'button_generate_password');
         $genButton->click();
 
-        $this->assertNotEquals("", $this->byId("text_pma_pw")->getAttribute('value'));
-        $this->assertNotEquals("", $this->byId("text_pma_pw2")->getAttribute('value'));
-        $this->assertNotEquals("", $this->byId("generated_pw")->getAttribute('value'));
+        $this->assertNotEquals('', $this->byId('text_pma_pw')->getAttribute('value'));
+        $this->assertNotEquals('', $this->byId('text_pma_pw2')->getAttribute('value'));
+        $this->assertNotEquals('', $this->byId('generated_pw')->getAttribute('value'));
 
-        $this->byId("text_pma_pw")->sendKeys($this->_txtPassword);
-        $this->byId("text_pma_pw2")->sendKeys($this->_txtPassword);
+        $this->byId('text_pma_pw')->sendKeys($this->txtPassword);
+        $this->byId('text_pma_pw2')->sendKeys($this->txtPassword);
 
         // Make sure the element is visible before clicking
         $this->scrollIntoView('createdb-1');
@@ -92,31 +90,31 @@ class CreateRemoveUserTest extends TestBase
         $this->waitForElement('id', 'createdb-2')->click();
 
         $this->scrollIntoView('addUsersForm_checkall');
-        $this->byId("addUsersForm_checkall")->click();
+        $this->byId('addUsersForm_checkall')->click();
 
         $this->scrollIntoView('adduser_submit');
-        $this->waitForElement('id', "adduser_submit")->click();
+        $this->waitForElement('id', 'adduser_submit')->click();
 
-        $success = $this->waitForElement('cssSelector', "div.success");
+        $success = $this->waitForElement('cssSelector', '.alert-success');
         $this->assertStringContainsString('You have added a new user', $success->getText());
 
         // Removing the newly added user
-        $this->waitForElement('partialLinkText', "User accounts")->click();
-        $el = $this->waitForElement('id', "usersForm");
-        $temp = $this->_txtUsername . "&amp;#27;localhost";
+        $this->waitForElement('partialLinkText', 'User accounts')->click();
+        $this->waitForElement('id', 'usersForm');
+        $temp = $this->txtUsername . '&amp;#27;localhost';
 
         $this->byXPath(
             "(//input[@name='selected_usr[]'])[@value='" . $temp . "']"
         )->click();
 
-        $this->scrollIntoView('fieldset_delete_user_footer');
-        $this->byId("checkbox_drop_users_db")->click();
+        $this->scrollIntoView('deleteUserCard');
+        $this->byId('dropUsersDbCheckbox')->click();
 
-        $this->byId("buttonGo")->click();
-        $this->waitForElement('cssSelector', "button.submitOK")->click();
+        $this->byId('buttonGo')->click();
+        $this->waitForElement('cssSelector', 'button.submitOK')->click();
         $this->acceptAlert();
 
-        $success = $this->waitForElement('cssSelector', "div.success");
+        $success = $this->waitForElement('cssSelector', '.alert-success');
         $this->assertStringContainsString(
             'The selected users have been deleted',
             $success->getText()
