@@ -1,11 +1,8 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Selenium TestCase for settings related tests
- *
- * @package    PhpMyAdmin-test
- * @subpackage Selenium
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Selenium;
@@ -13,38 +10,38 @@ namespace PhpMyAdmin\Tests\Selenium;
 /**
  * ServerSettingsTest class
  *
- * @package    PhpMyAdmin-test
- * @subpackage Selenium
  * @group      selenium
  */
 class ServerSettingsTest extends TestBase
 {
     /**
-     * setUp function
+     * Create a test database for this test class
      *
-     * @return void
+     * @var bool
+     */
+    protected static $createDatabase = false;
+
+    /**
+     * setUp function
      */
     protected function setUp(): void
     {
         parent::setUp();
         $this->login();
         $this->expandMore();
-        $this->maximize();
-        $this->waitForElement('partialLinkText', "Settings")->click();
+        $this->waitForElement('partialLinkText', 'Settings')->click();
         $this->waitAjax();
 
         $this->waitForElement(
             'xpath',
-            "//a[@class='tabactive' and contains(., 'Settings')]"
+            "//a[@class='nav-link text-nowrap' and contains(., 'Settings')]"
         );
     }
 
     /**
      * Saves config and asserts correct message.
-     *
-     * @return void
      */
-    private function _saveConfig()
+    private function saveConfig(): void
     {
         // Submit the form
         $ele = $this->waitForElement(
@@ -57,7 +54,7 @@ class ServerSettingsTest extends TestBase
 
         $this->waitUntilElementIsPresent(
             'xpath',
-            "//div[@class='success' and contains(., 'Configuration has been saved')]",
+            "//div[@class='alert alert-success' and contains(., 'Configuration has been saved')]",
             5000
         );
     }
@@ -65,87 +62,83 @@ class ServerSettingsTest extends TestBase
     /**
      * Tests whether hiding a database works or not
      *
-     * @return void
-     *
      * @group large
      */
-    public function testHideDatabase()
+    public function testHideDatabase(): void
     {
-        $this->byPartialLinkText("Features")->click();
+        $this->createDatabase();
+        $this->byPartialLinkText('Features')->click();
         $this->waitAjax();
 
         $this->waitForElement('xpath', "//a[contains(@href, '#Databases')]")->click();
 
-        $ele = $this->waitForElement('name', "Servers-1-hide_db");
+        $ele = $this->waitForElement('name', 'Servers-1-hide_db');
         $this->moveto($ele);
-        $ele->sendKeys($this->database_name);
+        $ele->clear();
+        $ele->sendKeys($this->databaseName);
 
-        $this->_saveConfig();
+        $this->saveConfig();
         $this->assertFalse(
-            $this->isElementPresent('partialLinkText', $this->database_name)
+            $this->isElementPresent('partialLinkText', $this->databaseName)
         );
 
-        $this->waitForElement('name', "Servers-1-hide_db")->clear();
-        $this->_saveConfig();
+        $this->waitForElement('name', 'Servers-1-hide_db')->clear();
+        $this->saveConfig();
         $this->assertTrue(
-            $this->isElementPresent('partialLinkText', $this->database_name)
+            $this->isElementPresent('partialLinkText', $this->databaseName)
         );
     }
 
     /**
      * Tests whether the various settings tabs are displayed when clicked
      *
-     * @return void
-     *
      * @group large
      */
-    public function testSettingsTabsAreDisplayed()
+    public function testSettingsTabsAreDisplayed(): void
     {
-        $this->byPartialLinkText("SQL queries")->click();
+        $this->byPartialLinkText('SQL queries')->click();
         $this->waitAjax();
 
         $this->waitForElement('className', 'tabs');
 
-        $this->byPartialLinkText("SQL Query box")->click();
+        $this->byPartialLinkText('SQL Query box')->click();
         $this->assertTrue(
-            $this->byId("Sql_box")->isDisplayed()
+            $this->byId('Sql_box')->isDisplayed()
         );
         $this->assertFalse(
-            $this->byId("Sql_queries")->isDisplayed()
+            $this->byId('Sql_queries')->isDisplayed()
         );
 
         $this->byCssSelector("a[href='#Sql_queries']")->click();
         $this->assertFalse(
-            $this->byId("Sql_box")->isDisplayed()
+            $this->byId('Sql_box')->isDisplayed()
         );
         $this->assertTrue(
-            $this->byId("Sql_queries")->isDisplayed()
+            $this->byId('Sql_queries')->isDisplayed()
         );
     }
 
     /**
      * Tests if hiding the logo works or not
      *
-     * @return void
-     *
      * @group large
      */
-    public function testHideLogo()
+    public function testHideLogo(): void
     {
-        $this->byPartialLinkText("Navigation panel")->click();
+        $this->byPartialLinkText('Navigation panel')->click();
         $this->waitAjax();
 
-        $this->waitForElement('name', "NavigationDisplayLogo")
+        $this->waitForElement('name', 'NavigationDisplayLogo')
             ->click();
-        $this->_saveConfig();
+        $this->saveConfig();
         $this->assertFalse(
-            $this->isElementPresent('id', "imgpmalogo")
+            $this->isElementPresent('id', 'imgpmalogo')
         );
 
         $this->byCssSelector("a[href='#NavigationDisplayLogo']")->click();
-        $this->_saveConfig();
+        $this->saveConfig();
         $this->assertTrue(
-            $this->isElementPresent('id', "imgpmalogo")
+            $this->isElementPresent('id', 'imgpmalogo')
         );
     }
 }
